@@ -2,7 +2,7 @@
 Diffusion Imaging in Python
 ============================
 
-For more information, please visit http://dipy.org
+For more information, please visit https://dipy.org
 
 Subpackages
 -----------
@@ -17,6 +17,7 @@ Subpackages
  denoise       -- Denoising algorithms
  direction     -- Manage peaks and tracking
  io            -- Loading/saving of dpy datasets
+ nn            -- Neural networks algorithms
  reconst       -- Signal reconstruction modules (tensor, spherical harmonics,
                   diffusion spectrum, etc.)
  segment       -- Tractography segmentation
@@ -24,6 +25,7 @@ Subpackages
  stats         -- Tractometry
  tracking      -- Tractography, metrics for streamlines
  viz           -- Visualization and GUIs
+ workflows      -- Predefined Command line for common tasks
 
 Utilities
 ---------
@@ -35,12 +37,39 @@ Utilities
 """
 import sys
 
-from .info import __version__
+from dipy.version import version as __version__
 from .testing import setup_test
 
 # Plumb in version etc info stuff
 from .pkg_info import get_pkg_info as _get_pkg_info
+
+
 def get_info():
     from os.path import dirname
     return _get_pkg_info(dirname(__file__))
+
+
 del sys
+
+submodules = [
+    'align',
+    'boots',
+    'core',
+    'data',
+    'denoise',
+    'direction',
+    'io',
+    'nn',
+    'reconst',
+    'segment',
+    'sims',
+    'stats',
+    'tracking',
+    'utils',
+    'viz',
+    'workflows',
+    'tests',
+    'testing'
+]
+
+__all__ = submodules + ['__version__', 'setup_test', 'get_info']
