@@ -1,11 +1,11 @@
 import os.path as op
 import pytest
+from tempfile import TemporaryDirectory
 
 import numpy as np
 import numpy.testing as npt
 
 import nibabel as nib
-import nibabel.tmpdirs as nbtmp
 
 import dipy.data as dpd
 import dipy.core.gradients as dpg
@@ -21,6 +21,9 @@ from dipy.align.imwarp import DiffeomorphicMap
 from dipy.tracking.utils import transform_tracking_output
 from dipy.io.streamline import save_trk
 from dipy.io.stateful_tractogram import StatefulTractogram, Space
+from dipy.io.gradients import read_bvals_bvecs
+from dipy.io.image import load_nifti
+from dipy.testing.decorators import set_random_number_generator
 
 
 def setup_module():
@@ -45,7 +48,7 @@ def setup_module():
 
 
 def test_syn_registration():
-    with nbtmp.InTemporaryDirectory() as tmpdir:
+    with TemporaryDirectory() as tmpdir:
         warped_moving, mapping = syn_registration(subset_b0,
                                                   subset_t2,
                                                   moving_affine=hardi_affine,
@@ -223,7 +226,7 @@ def test_register_series():
 
 def test_register_dwi_series_and_motion_correction():
     fdata, fbval, fbvec = dpd.get_fnames('small_64D')
-    with nbtmp.InTemporaryDirectory() as tmpdir:
+    with TemporaryDirectory() as tmpdir:
         # Use an abbreviated data-set:
         img = nib.load(fdata)
         data = img.get_fdata()[..., :10]
@@ -244,11 +247,12 @@ def test_register_dwi_series_and_motion_correction():
         npt.assert_array_equal(reg_affines, reg_affines_2)
 
 
-def test_streamline_registration():
+@set_random_number_generator()
+def test_streamline_registration(rng):
     sl1 = [np.array([[0, 0, 0], [0, 0, 0.5], [0, 0, 1], [0, 0, 1.5]]),
            np.array([[0, 0, 0], [0, 0.5, 0.5], [0, 1, 1]])]
     affine_mat = np.eye(4)
-    affine_mat[:3, 3] = np.random.randn(3)
+    affine_mat[:3, 3] = rng.standard_normal(3)
     sl2 = list(transform_tracking_output(sl1, affine_mat))
     aligned, matrix = streamline_registration(sl2, sl1)
     npt.assert_almost_equal(matrix, np.linalg.inv(affine_mat))
@@ -257,11 +261,11 @@ def test_streamline_registration():
 
     # We assume the two tracks come from the same space, but it might have
     # some affine associated with it:
-    base_aff = np.eye(4) * np.random.rand()
+    base_aff = np.eye(4) * rng.random()
     base_aff[:3, 3] = np.array([1, 2, 3])
     base_aff[3, 3] = 1
 
-    with nbtmp.InTemporaryDirectory() as tmpdir:
+    with TemporaryDirectory() as tmpdir:
         for use_aff in [None, base_aff]:
             fname1 = op.join(tmpdir, 'sl1.trk')
             fname2 = op.join(tmpdir, 'sl2.trk')
@@ -292,3 +296,18 @@ def test_streamline_registration():
             aligned, matrix = streamline_registration(fname2, fname1)
             npt.assert_almost_equal(aligned[0], sl1[0], decimal=5)
             npt.assert_almost_equal(aligned[1], sl1[1], decimal=5)
+
+
+def test_register_dwi_series_multi_b0():
+    # Test if register_dwi_series works with multiple b0 images
+    dwi_fname, dwi_bval_fname, \
+        dwi_bvec_fname = dpd.get_fnames('sherbrooke_3shell')
+    data, affine = load_nifti(dwi_fname)
+    bvals, bvecs = read_bvals_bvecs(dwi_bval_fname, dwi_bvec_fname)
+
+    data_small = data[..., :3]
+    data_small = np.concatenate([data[..., :1], data_small], axis=-1)
+    bvals_small = np.concatenate([bvals[:1], bvals[:3]], axis=0)
+    bvecs_small = np.concatenate([bvecs[:1], bvecs[:3]], axis=0)
+    gtab = dpg.gradient_table(bvals_small, bvecs_small)
+    _ = motion_correction(data_small, gtab, affine)
