@@ -12,6 +12,7 @@ from dipy.align.imaffine import AffineInversionError, AffineInvalidValuesError,
     AffineMap, _number_dim_affine_matrix
 from dipy.align.transforms import regtransforms
 from dipy.align.tests.test_parzenhist import setup_random_transform
+from dipy.testing.decorators import set_random_number_generator
 
 # For each transform type, select a transform factor (indicating how large the
 # true transform between static and moving images will be), a sampling scheme
@@ -36,7 +37,6 @@ factors = {('TRANSLATION', 2): (2.0, 0.35, np.array([2.3, 4.5])),
 
 
 def test_transform_centers_of_mass_3d():
-    np.random.seed(1246592)
     shape = (64, 64, 64)
     rm = 8
     sph = vf.create_sphere(shape[0] // 2, shape[1] // 2, shape[2] // 2, rm)
@@ -175,7 +175,8 @@ def test_transform_origins_3d():
                     assert_array_almost_equal(actual.affine, expected)
 
 
-def test_affreg_all_transforms():
+@set_random_number_generator(202311)
+def test_affreg_all_transforms(rng):
     # Test affine registration using all transforms with typical settings
 
     # Make sure dictionary entries are processed in the same order regardless
@@ -198,7 +199,8 @@ def test_affreg_all_transforms():
                                                                       trans,
                                                                       factor,
                                                                       nslices,
-                                                                      1.0)
+                                                                      1.0,
+                                                                      rng=rng)
         # Sum of absolute differences
         start_sad = np.abs(static - moving).sum()
         metric = imaffine.MutualInformationMetric(32, sampling_pc)
@@ -243,7 +245,8 @@ def test_affreg_all_transforms():
                               np.zeros_like(smask), np.zeros_like(mmask))
 
 
-def test_affreg_defaults():
+@set_random_number_generator(202311)
+def test_affreg_defaults(rng):
     # Test all default arguments with an arbitrary transform
     # Select an arbitrary transform (all of them are already tested
     # in test_affreg_all_transforms)
@@ -260,7 +263,7 @@ def test_affreg_defaults():
         factor = factors[ttype][0]
         transform = regtransforms[ttype]
         static, moving, static_grid2world, moving_grid2world, smask, mmask, T = \
-            setup_random_transform(transform, factor, nslices, 1.0)
+            setup_random_transform(transform, factor, nslices, 1.0, rng=rng)
         # Sum of absolute differences
         start_sad = np.abs(static - moving).sum()
 
@@ -297,11 +300,11 @@ def test_affreg_defaults():
             end_sad = np.abs(moving - transformed_inv).sum()
             reduction = 1 - end_sad / start_sad
             print("%s>>%f" % (ttype, reduction))
-            assert(reduction > 0.9)
+            assert(reduction > 0.89)
 
 
-def test_mi_gradient():
-    np.random.seed(2022966)
+@set_random_number_generator(2022966)
+def test_mi_gradient(rng):
     # Test the gradient of mutual information
     h = 1e-5
     # Make sure dictionary entries are processed in the same order regardless
@@ -322,10 +325,11 @@ def test_mi_gradient():
         # Start from a small rotation
         start = regtransforms[('ROTATION', dim)]
         nrot = start.get_number_of_parameters()
-        starting_affine = start.param_to_matrix(0.25 * np.random.randn(nrot))
+        starting_affine = \
+            start.param_to_matrix(0.25 * rng.standard_normal(nrot))
         # Get data (pair of images related to each other by an known transform)
         static, moving, static_g2w, moving_g2w, smask, mmask, M = \
-            setup_random_transform(transform, factor, nslices, 2.0)
+            setup_random_transform(transform, factor, nslices, 2.0, rng=rng)
 
         # Prepare a MutualInformationMetric instance
         mi_metric = imaffine.MutualInformationMetric(32, sampling_proportion)
@@ -413,8 +417,8 @@ def create_affine_transforms(
     return transforms
 
 
-def test_affine_map():
-    np.random.seed(2112927)
+@set_random_number_generator(2112927)
+def test_affine_map(rng):
     dom_shape = np.array([64, 64, 64], dtype=np.int32)
     cod_shape = np.array([80, 80, 80], dtype=np.int32)
     # Radius of the circle/sphere (testing image)
@@ -603,14 +607,15 @@ def test_affine_map():
     # Verify AffineMap can not be created with non-2D matrices : len(shape) != 2
     for dim_not_2 in range(10):
         if dim_not_2 != _number_dim_affine_matrix:
-            mat_large_dim = np.random.random([2]*dim_not_2)
+            mat_large_dim = rng.random([2]*dim_not_2)
             assert_raises(AffineInversionError, AffineMap, mat_large_dim)
 
 
-def test_MIMetric_invalid_params():
+@set_random_number_generator()
+def test_MIMetric_invalid_params(rng):
     transform = regtransforms[('AFFINE', 3)]
-    static = np.random.rand(20, 20, 20)
-    moving = np.random.rand(20, 20, 20)
+    static = rng.random((20, 20, 20))
+    moving = rng.random((20, 20, 20))
     n = transform.get_number_of_parameters()
     sampling_proportion = 0.3
     theta_sing = np.zeros(n)
