@@ -51,7 +51,7 @@ References
 [1] How-To Guide for Descriptors, Raymond
 Hettinger. http://users.rcn.com/python/download/Descriptor.htm
 
-[2] Python data model, http://docs.python.org/reference/datamodel.html
+[2] Python data model, https://docs.python.org/reference/datamodel.html
 """
 
 # ----------------------------------------------------------------------------
@@ -59,7 +59,7 @@ Hettinger. http://users.rcn.com/python/download/Descriptor.htm
 # ----------------------------------------------------------------------------
 
 
-class ResetMixin(object):
+class ResetMixin:
     """A Mixin class to add a .reset() method to users of OneTimeProperty.
 
     By default, auto attributes once computed, become static.  If they happen
@@ -141,7 +141,7 @@ class ResetMixin(object):
                 delattr(self, mname)
 
 
-class OneTimeProperty(object):
+class OneTimeProperty:
     """A descriptor to make special properties that become normal attributes.
 
     This is meant to be used mostly by the auto_attr decorator in this module.
@@ -189,7 +189,7 @@ def auto_attr(func):
 
     Examples
     --------
-    >>> class MagicProp(object):
+    >>> class MagicProp:
     ...     @auto_attr
     ...     def a(self):
     ...         return 99
