@@ -8,8 +8,9 @@ from dipy.utils.optpkg import optional_package
 
 cProfile, _, _ = optional_package('cProfile')
 pstats, _, _ = optional_package('pstats',
-                                'pstats is not installed.  It is part of the'
-                                'python-profiler package in Debian/Ubuntu')
+                                trip_msg='pstats is not installed.  It is '
+                                'part of the python-profiler package in '
+                                'Debian/Ubuntu')
 
 
 class Profiler:
@@ -44,9 +45,9 @@ class Profiler:
 
     References
     ----------
-    http://docs.cython.org/src/tutorial/profiling_tutorial.html
-    http://docs.python.org/library/profile.html
-    http://packages.python.org/line_profiler/
+    https://docs.cython.org/src/tutorial/profiling_tutorial.html
+    https://docs.python.org/library/profile.html
+    https://github.com/rkern/line_profiler
 
     """
 
@@ -60,7 +61,7 @@ class Profiler:
 
             ext = os.path.splitext(call)[1].lower()
             print('ext', ext)
-            if ext == '.py' or ext == '.pyx':  # python/cython file
+            if ext in ('.py', '.pyx'):  # python/cython file
                 print('profiling python/cython file ...')
                 subprocess.call(['python', '-m', 'cProfile',
                                  '-o', 'profile.prof', call])
