@@ -2,13 +2,17 @@ import warnings
 
 import numpy as np
 import numpy.testing as npt
+import pytest
 
 from dipy.data import get_fnames
-from dipy.core.gradients import (gradient_table, GradientTable,
+from dipy.core.gradients import (b0_threshold_empty_gradient_message,
+                                 b0_threshold_update_slicing_message,
+                                 gradient_table, GradientTable,
                                  gradient_table_from_bvals_bvecs,
                                  gradient_table_from_qvals_bvecs,
                                  gradient_table_from_gradient_strength_bvecs,
                                  WATER_GYROMAGNETIC_RATIO,
+                                 mask_non_weighted_bvals,
                                  orientation_to_string,
                                  reorient_bvecs, generate_bvecs,
                                  check_multi_b, round_bvals, get_bval_indices,
@@ -20,6 +24,7 @@ from dipy.core.geometry import vec2vec_rotmat, vector_norm
 from dipy.io.gradients import read_bvals_bvecs
 from dipy.utils.deprecator import ExpiredDeprecationError
 from dipy.testing import clear_and_catch_warnings
+from dipy.testing.decorators import set_random_number_generator
 
 
 def test_unique_bvals_deprecated():
@@ -27,6 +32,24 @@ def test_unique_bvals_deprecated():
                       np.array([0, 800, 1400, 1401, 1405]))
 
 
+def test_mask_non_weighted_bvals():
+
+    bvals = np.array([0., 100., 200., 300., 400.])
+    b0_threshold = 0.
+    expected_val = np.asarray([True, False, False, False, False])
+    obtained_val = mask_non_weighted_bvals(bvals, b0_threshold)
+    assert np.array_equal(obtained_val, expected_val)
+
+    b0_threshold = 50
+    obtained_val = mask_non_weighted_bvals(bvals, b0_threshold)
+    assert np.array_equal(obtained_val, expected_val)
+
+    b0_threshold = 200.
+    expected_val = np.asarray([True, True, True, False, False])
+    obtained_val = mask_non_weighted_bvals(bvals, b0_threshold)
+    assert np.array_equal(obtained_val, expected_val)
+
+
 def test_btable_prepare():
 
     sq2 = np.sqrt(2) / 2.
@@ -354,7 +377,8 @@ def test_qvalues():
     npt.assert_almost_equal(bt.qvals, qvals)
 
 
-def test_reorient_bvecs():
+@set_random_number_generator()
+def test_reorient_bvecs(rng):
     sq2 = np.sqrt(2) / 2
     bvals = np.concatenate([[0], np.ones(6) * 1000])
     bvecs = np.array([[0, 0, 0],
@@ -367,9 +391,9 @@ def test_reorient_bvecs():
 
     gt = gradient_table_from_bvals_bvecs(bvals, bvecs, b0_threshold=0)
     # The simple case: all affines are identity
-    affs = np.zeros((6, 4, 4))
+    affs = np.zeros((4, 4, 6))
     for i in range(4):
-        affs[:, i, i] = 1
+        affs[i, i, :] = 1
 
     # We should get back the same b-vectors
     new_gt = reorient_bvecs(gt, affs)
@@ -379,7 +403,7 @@ def test_reorient_bvecs():
     rotation_affines = []
     rotated_bvecs = bvecs[:]
     for i in np.where(~gt.b0s_mask)[0]:
-        rot_ang = np.random.rand()
+        rot_ang = rng.random()
         cos_rot = np.cos(rot_ang)
         sin_rot = np.sin(rot_ang)
         rotation_affines.append(np.array([[1, 0, 0, 0],
@@ -389,15 +413,16 @@ def test_reorient_bvecs():
         rotated_bvecs[i] = np.dot(rotation_affines[-1][:3, :3],
                                   bvecs[i])
 
+    rotation_affines = np.stack(rotation_affines, axis=-1)
     # Copy over the rotation affines
     full_affines = rotation_affines[:]
     # And add some scaling and translation to each one to make this harder
-    for i in range(len(full_affines)):
-        full_affines[i] = np.dot(full_affines[i],
-                                 np.array([[2.5, 0, 0, -10],
-                                           [0, 2.2, 0, 20],
-                                           [0, 0, 1, 0],
-                                           [0, 0, 0, 1]]))
+    for i in range(full_affines.shape[-1]):
+        full_affines[..., i] = np.dot(full_affines[..., i],
+                                      np.array([[2.5, 0, 0, -10],
+                                                [0, 2.2, 0, 20],
+                                                [0, 0, 1, 0],
+                                                [0, 0, 0, 1]]))
 
     gt_rot = gradient_table_from_bvals_bvecs(bvals,
                                              rotated_bvecs, b0_threshold=0)
@@ -408,11 +433,11 @@ def test_reorient_bvecs():
 
     # We should be able to pass just the 3-by-3 rotation components to the same
     # effect
-    new_gt = reorient_bvecs(gt_rot, np.array(rotation_affines)[:, :3, :3])
+    new_gt = reorient_bvecs(gt_rot, np.array(rotation_affines)[:3, :3])
     npt.assert_almost_equal(gt.bvecs, new_gt.bvecs)
 
     # Verify that giving the wrong number of affines raises an error:
-    full_affines.append(np.zeros((4, 4)))
+    full_affines = np.concatenate([full_affines, np.zeros((4, 4, 1))], axis=-1)
     npt.assert_raises(ValueError, reorient_bvecs, gt_rot, full_affines)
 
     # Shear components in the matrix need to be decomposed into rotation only,
@@ -423,9 +448,10 @@ def test_reorient_bvecs():
                                        [0, 1, 0, 0],
                                        [0, 0, 1, 0],
                                        [0, 0, 0, 1]]))
+    shear_affines = np.stack(shear_affines, axis=-1)
     # atol is set to 1 here to do the scaling verification here,
     # so that the reorient_bvecs function does not throw an error itself
-    new_gt = reorient_bvecs(gt, np.array(shear_affines)[:, :3, :3], atol=1)
+    new_gt = reorient_bvecs(gt, shear_affines[:3, :3], atol=1)
     bvecs_close_to_1 = abs(vector_norm(new_gt.bvecs[~gt.b0s_mask]) - 1) <= 0.001
     npt.assert_(np.all(bvecs_close_to_1))
 
@@ -447,29 +473,41 @@ def test_nan_bvecs():
         npt.assert_(len(selected_w) == 0)
 
 
-def test_generate_bvecs():
+@set_random_number_generator()
+def test_generate_bvecs(rng):
     """Tests whether we have properly generated bvecs.
     """
     # Test if the generated b-vectors are unit vectors
-    bvecs = generate_bvecs(100)
+    bvecs = generate_bvecs(100, rng=rng)
     norm = [np.linalg.norm(v) for v in bvecs]
     npt.assert_almost_equal(norm, np.ones(100))
 
     # Test if two generated vectors are almost orthogonal
-    bvecs_2 = generate_bvecs(2)
+    bvecs_2 = generate_bvecs(2, rng=rng)
     cos_theta = np.dot(bvecs_2[0], bvecs_2[1])
     npt.assert_almost_equal(cos_theta, 0., decimal=6)
 
 
 def test_getitem_idx():
     # Create a GradientTable object with some test b-values and b-vectors
-    bvals = np.array([0, 100, 200, 300, 400])
+    bvals = np.array([0., 100., 200., 300., 400.])
     # value should be in increasing order as b-value affects the diffusion
     # weighting of the image, and the amount of diffusion weighting increases
     # with increasing b-value.
     bvecs = np.array([[0, 0, 1], [1, 0, 0], [0, 1, 0], [0, 0, 1], [1, 0, 0]])
     # the b-vectors should be unit-length vectors
     gradients = bvals[:, None] * bvecs
+
+    # Test a too large b0 threshold value
+    b0_threshold = 100
+    gtab = GradientTable(gradients, b0_threshold=b0_threshold)
+
+    idx = 1
+    with pytest.raises(ValueError) as excinfo:
+        _ = gtab[idx]
+        assert str(excinfo.value) == b0_threshold_empty_gradient_message(
+            bvals, [idx], b0_threshold)
+
     gtab = GradientTable(gradients)
 
     # Test with a single index
@@ -478,11 +516,18 @@ def test_getitem_idx():
     assert np.array_equal(gtab_slice1.bvecs, np.array([[1., 0., 0.]]))
 
     # Test with a range of indices
-    gtab_slice2 = gtab[2:5]
-    assert np.array_equal(gtab_slice2.bvals, np.array([200., 300., 400.]))
-    assert np.array_equal(gtab_slice2.bvecs,
-                          np.array([[0., 1., 0.], [0., 0., 1.],
-                                    [1., 0., 0.]]))
+    gtab = GradientTable(gradients)
+    idx_start = 2
+    idx_end = 5
+    with warnings.catch_warnings():
+        warnings.filterwarnings(
+            "ignore", message=b0_threshold_update_slicing_message(idx_start),
+            category=UserWarning)
+        gtab_slice2 = gtab[idx_start:idx_end]
+        assert np.array_equal(gtab_slice2.bvals, np.array([200., 300., 400.]))
+        assert np.array_equal(gtab_slice2.bvecs,
+                              np.array([[0., 1., 0.], [0., 0., 1.],
+                                        [1., 0., 0.]]))
 
 
 def test_round_bvals():
@@ -623,7 +668,8 @@ def test_check_multi_b():
     npt.assert_(check_multi_b(gtab, 2, non_zero=False))
 
 
-def test_btens_to_params():
+@set_random_number_generator()
+def test_btens_to_params(rng):
     """
     Checks if bvals, bdeltas and b_etas are as expected for 4 b-tensor shapes
     (LTE, PTE, STE, CTE) as well as scaled and rotated versions of them
@@ -685,14 +731,14 @@ def test_btens_to_params():
     # Test function after rotating+scaling baseline tensors
     # -----------------------------------------------------
 
-    scales = np.concatenate((np.array([1]), np.random.random(n_scales)))
+    scales = np.concatenate((np.array([1]), rng.random(n_scales)))
 
     for scale in scales:
 
         ebs = expected_bvals*scale
 
         # Generate `n_rotations` random 3-element vectors of norm 1
-        v = np.random.random((n_rotations, 3)) - 0.5
+        v = rng.random((n_rotations, 3)) - 0.5
         u = np.apply_along_axis(lambda w: w/np.linalg.norm(w), axis=1, arr=v)
 
         for rot_idx in range(n_rotations):
@@ -828,3 +874,28 @@ def test_reorient_vectors():
         npt.assert_array_equal(reorient_vectors(bvec, 'asr', 'iar', axis=1),
                                result)
     bvec = np.arange(12).reshape((3, 4))
+
+
+def test_affine_input_change():
+    sq2 = np.sqrt(2) / 2
+    bvals = np.concatenate([[0], np.ones(6) * 1000])
+    bvecs = np.array([[0, 0, 0],
+                      [1, 0, 0],
+                      [0, 1, 0],
+                      [0, 0, 1],
+                      [sq2, sq2, 0],
+                      [sq2, 0, sq2],
+                      [0, sq2, sq2]])
+
+    gt = gradient_table_from_bvals_bvecs(bvals, bvecs, b0_threshold=0)
+    
+    # Wrong affine dimension
+    affs = np.zeros((6, 4, 4))
+    for i in range(4):
+        affs[:, i, i] = 1
+
+    npt.assert_warns(Warning, reorient_bvecs, gt, affs)
+
+    # Check if list still works
+    affs = [np.eye(4) for _ in range(6)]
+    _ = reorient_bvecs(gt, affs)
