@@ -1,5 +1,3 @@
-import numpy as np
-import numpy.testing as npt
 from dipy.denoise.noise_estimate import estimate_sigma
 from dipy.denoise.nlmeans import nlmeans
 import dipy.data as dpd
