@@ -8,6 +8,7 @@ from dipy.denoise.pca_noise_estimate import pca_noise_estimate
 import dipy.data as dpd
 import dipy.core.gradients as dpg
 from dipy.io.image import load_nifti_data
+from dipy.testing.decorators import set_random_number_generator
 
 
 def test_inv_nchi():
@@ -25,7 +26,8 @@ def test_inv_nchi():
     assert_almost_equal(lambdaPlus, 9.722849086419043)
 
 
-def test_piesno():
+@set_random_number_generator()
+def test_piesno(rng):
     # Values taken from hispeed.OptimalPIESNO with the test data
     # in the package computed in matlab
     test_piesno_data = load_nifti_data(dpd.get_fnames("test_piesno"))
@@ -33,8 +35,8 @@ def test_piesno():
                    return_mask=False)
     assert_almost_equal(sigma, 0.010749458025559)
 
-    noise1 = (np.random.randn(100, 100, 100) * 50) + 10
-    noise2 = (np.random.randn(100, 100, 100) * 50) + 10
+    noise1 = (rng.standard_normal((100, 100, 100)) * 50) + 10
+    noise2 = (rng.standard_normal((100, 100, 100)) * 50) + 10
     rician_noise = np.sqrt(noise1**2 + noise2**2)
     sigma, mask = piesno(rician_noise, N=1, alpha=0.01, l=1, eps=1e-10,
                          return_mask=True)
@@ -141,8 +143,8 @@ def test_estimate_sigma():
                                                np.sqrt(0.4946862482541263)]))
 
 
-def test_pca_noise_estimate():
-    np.random.seed(1984)
+@set_random_number_generator(1984)
+def test_pca_noise_estimate(rng):
     # MUBE:
     bvals1 = np.concatenate([np.zeros(17), np.ones(3) * 1000])
     bvecs1 = np.concatenate([np.zeros((17, 3)), np.eye(3)])
@@ -164,8 +166,8 @@ def test_pca_noise_estimate():
                             signal = signal * 100
 
                         sigma = 1
-                        noise1 = np.random.normal(0, sigma, size=signal.shape)
-                        noise2 = np.random.normal(0, sigma, size=signal.shape)
+                        noise1 = rng.normal(0, sigma, size=signal.shape)
+                        noise2 = rng.normal(0, sigma, size=signal.shape)
 
                         # Rician noise:
                         data = np.sqrt((signal + noise1) ** 2 + noise2 ** 2)
