@@ -1,5 +1,3 @@
-from __future__ import division, print_function, absolute_import
-
 import os
 import numpy as np
 
@@ -42,7 +40,7 @@ def load_peaks(fname, verbose=False):
     """
 
     if os.path.splitext(fname)[1].lower() != '.pam5':
-        raise IOError('This function supports only PAM5 (HDF5) files')
+        raise OSError('This function supports only PAM5 (HDF5) files')
 
     f = h5py.File(fname, 'r')
 
@@ -53,7 +51,7 @@ def load_peaks(fname, verbose=False):
     version = f.attrs['version']
 
     if version != '0.0.1':
-        raise IOError('Incorrect PAM5 file version {0}'.format(version,))
+        raise OSError('Incorrect PAM5 file version {0}'.format(version,))
 
     try:
         affine = pamh['affine'][:]
@@ -137,7 +135,7 @@ def save_peaks(fname, pam, affine=None, verbose=False):
     """
 
     if os.path.splitext(fname)[1] != '.pam5':
-        raise IOError('This function saves only PAM5 (HDF5) files')
+        raise OSError('This function saves only PAM5 (HDF5) files')
 
     if not (hasattr(pam, 'peak_dirs') and hasattr(pam, 'peak_values') and
             hasattr(pam, 'peak_indices')):
@@ -149,7 +147,7 @@ def save_peaks(fname, pam, affine=None, verbose=False):
     f = h5py.File(fname, 'w')
 
     group = f.create_group('pam')
-    f.attrs['version'] = u'0.0.1'
+    f.attrs['version'] = '0.0.1'
 
     version_string = f.attrs['version']
 
