@@ -1,8 +1,7 @@
-
 import numpy as np
 from dipy.tracking.streamline import transform_streamlines
 from dipy.utils.optpkg import optional_package
-fury, have_fury, setup_module = optional_package('fury')
+fury, have_fury, setup_module = optional_package('fury', min_version="0.9.0")
 
 if have_fury:
     import fury.utils
