@@ -2,9 +2,6 @@
 """
 Class and helper functions for fitting the Synb0 model.
 """
-
-
-from packaging.version import Version
 import logging
 import numpy as np
 
@@ -13,7 +10,7 @@ from dipy.testing.decorators import doctest_skip_parser
 from dipy.utils.optpkg import optional_package
 from dipy.nn.utils import normalize, unnormalize, set_logger_level
 
-tf, have_tf, _ = optional_package('tensorflow')
+tf, have_tf, _ = optional_package('tensorflow', min_version='2.0.0')
 tfa, have_tfa, _ = optional_package('tensorflow_addons')
 if have_tf and have_tfa:
     from tensorflow.keras.models import Model
@@ -21,8 +18,6 @@ if have_tf and have_tfa:
     from tensorflow.keras.layers import Conv3D, LeakyReLU
     from tensorflow.keras.layers import Concatenate, Layer
     from tensorflow_addons.layers import InstanceNormalization
-    if Version(tf.__version__) < Version('2.0.0'):
-        raise ImportError('Please upgrade to TensorFlow 2+')
 else:
     class Model:
         pass
@@ -77,7 +72,7 @@ class DecoderBlock(Layer):
 def UNet3D(input_shape):
     r"""
     Function to create model for Synb0
-    
+
     Parameters
     ----------
     input_shape : tuple
@@ -93,7 +88,7 @@ def UNet3D(input_shape):
                      strides=1, padding='same')(inputs)
     syn0 = EncoderBlock(64, kernel_size=3,
                         strides=1, padding='same')(x)
-    
+
     x = MaxPool3D()(syn0)
     x = EncoderBlock(64, kernel_size=3,
                      strides=1, padding='same')(x)
@@ -115,7 +110,7 @@ def UNet3D(input_shape):
     # Last layer without relu
     x = Conv3D(512, kernel_size=1,
                strides=1, padding='same')(x)
-    
+
     x = DecoderBlock(512, kernel_size=2,
                      strides=2, padding='valid')(x)
 
@@ -127,7 +122,7 @@ def UNet3D(input_shape):
                      strides=1, padding='same')(x)
     x = DecoderBlock(256, kernel_size=2,
                      strides=2, padding='valid')(x)
-    
+
     x = Concatenate()([x, syn1])
 
     x = DecoderBlock(128, kernel_size=3,
@@ -255,7 +250,7 @@ def UNet3D(input_shape):
                      strides=1, padding='same')(inputs)
     syn0 = EncoderBlock(64, kernel_size=3,
                         strides=1, padding='same')(x)
-    
+
     x = MaxPool3D()(syn0)
     x = EncoderBlock(64, kernel_size=3,
                      strides=1, padding='same')(x)
@@ -277,7 +272,7 @@ def UNet3D(input_shape):
     # Last layer without relu
     x = Conv3D(512, kernel_size=1,
                strides=1, padding='same')(x)
-    
+
     x = DecoderBlock(512, kernel_size=2,
                      strides=2, padding='valid')(x)
 
@@ -289,7 +284,7 @@ def UNet3D(input_shape):
                      strides=1, padding='same')(x)
     x = DecoderBlock(256, kernel_size=2,
                      strides=2, padding='valid')(x)
-    
+
     x = Concatenate()([x, syn1])
 
     x = DecoderBlock(128, kernel_size=3,
