@@ -1,17 +1,16 @@
 import pytest
-from packaging.version import Version
+
+import numpy as np
+import numpy.testing as npt
 
 from dipy.data import get_fnames
 from dipy.utils.optpkg import optional_package
-import numpy as np
-from numpy.testing import assert_almost_equal
 
-tf, have_tf, _ = optional_package('tensorflow')
+tf, have_tf, _ = optional_package('tensorflow', min_version='2.0.0')
 
 if have_tf:
     from dipy.nn.evac import EVACPlus
-    if Version(tf.__version__) < Version('2.0.0'):
-        raise ImportError('Please upgrade to TensorFlow 2+')
+
 
 @pytest.mark.skipif(not have_tf, reason='Requires TensorFlow')
 def test_default_weights():
@@ -21,7 +20,7 @@ def test_default_weights():
 
     evac_model = EVACPlus()
     results_arr = evac_model.predict(input_arr, np.eye(4), return_prob=True)
-    assert_almost_equal(results_arr, output_arr, decimal=4)
+    npt.assert_almost_equal(results_arr, output_arr, decimal=4)
 
 
 @pytest.mark.skipif(not have_tf, reason='Requires TensorFlow')
@@ -35,4 +34,12 @@ def test_default_weights_batch():
     fake_affine = np.array([np.eye(4), np.eye(4)])
     fake_voxsize = np.ones((2, 3))
     results_arr = evac_model.predict(input_arr, fake_affine, fake_voxsize, batch_size=2, return_prob=True)
-    assert_almost_equal(results_arr, output_arr, decimal=4)
+    npt.assert_almost_equal(results_arr, output_arr, decimal=4)
+
+
+@pytest.mark.skipif(not have_tf, reason='Requires TensorFlow')
+def test_T1_error():
+    T1 = np.ones((3, 32, 32, 32))
+    evac_model = EVACPlus()
+    fake_affine = np.array([np.eye(4), np.eye(4), np.eye(4)])
+    npt.assert_raises(ValueError, evac_model.predict, T1, fake_affine)
\ No newline at end of file
