@@ -11,7 +11,7 @@ particular set of data (different voxels, for example).
 """
 
 
-class ReconstModel(object):
+class ReconstModel:
     """ Abstract class for signal reconstruction models
     """
 
@@ -29,7 +29,7 @@ class ReconstModel(object):
         return ReconstFit(self, data)
 
 
-class ReconstFit(object):
+class ReconstFit:
     """ Abstract class which holds the fit result of ReconstModel
 
     For example that could be holding FA or GFA etc.
