@@ -1,7 +1,7 @@
 from dipy.core.onetime import auto_attr
 
 
-class Cache(object):
+class Cache:
     """Cache values based on a key object (such as a sphere or gradient table).
 
     Notes
