@@ -1,6 +1,4 @@
-
 from warnings import warn
-from packaging.version import Version
 
 import numpy as np
 
@@ -14,7 +12,8 @@ from dipy.data import default_sphere
 from dipy.reconst.odf import OdfModel, OdfFit
 from scipy.optimize import leastsq
 from dipy.utils.optpkg import optional_package
-cvxpy, have_cvxpy, _ = optional_package("cvxpy")
+
+cvxpy, have_cvxpy, _ = optional_package("cvxpy", min_version="1.4.1")
 
 
 class ForecastModel(OdfModel, Cache):
@@ -44,7 +43,7 @@ class ForecastModel(OdfModel, Cache):
 
     Notes
     -----
-    The implementation of FORECAST may require CVXPY (http://www.cvxpy.org/).
+    The implementation of FORECAST may require CVXPY (https://www.cvxpy.org/).
     """
 
     def __init__(self,
@@ -182,12 +181,11 @@ class ForecastModel(OdfModel, Cache):
         self.pos = False
 
         if dec_alg.upper() == 'POS':
-            if have_cvxpy:
-                self.wls = False
-                self.pos = True
-            else:
-                msg = 'cvxpy is needed to enforce positivity constraints.'
-                raise ValueError(msg)
+            if not have_cvxpy:
+                cvxpy.import_error()
+
+            self.wls = False
+            self.pos = True
 
         if dec_alg.upper() == 'CSD':
             self.csd = True
@@ -221,9 +219,7 @@ class ForecastModel(OdfModel, Cache):
         d_perp = np.cos(x[1])**2 * 3e-03
 
         if d_perp >= d_par:
-            temp = d_par
-            d_par = d_perp
-            d_perp = temp
+            d_par, d_perp = d_perp, d_par
 
         # round to avoid memory explosion
         diff_key = str(int(np.round(d_par * 1e05))) + \
@@ -262,18 +258,12 @@ class ForecastModel(OdfModel, Cache):
 
             if self.pos:
                 c = cvxpy.Variable(M.shape[1])
-                if Version(cvxpy.__version__) < Version('1.1'):
-                    design_matrix = cvxpy.Constant(M) * c
-                else:
-                    design_matrix = cvxpy.Constant(M) @ c
+                design_matrix = cvxpy.Constant(M) @ c
                 objective = cvxpy.Minimize(
                     cvxpy.sum_squares(design_matrix - data_single_b0) +
                     self.lambda_lb * cvxpy.quad_form(c, self.lb_matrix))
 
-                if Version(cvxpy.__version__) < Version('1.1'):
-                    constraints = [c[0] == c0, self.fod * c >= 0]
-                else:
-                    constraints = [c[0] == c0, self.fod @ c >= 0]
+                constraints = [c[0] == c0, self.fod @ c >= 0]
                 prob = cvxpy.Problem(objective, constraints)
                 try:
                     prob.solve(solver=cvxpy.OSQP, eps_abs=1e-05, eps_rel=1e-05)
@@ -440,9 +430,7 @@ def forecast_error_func(x, b_unique, E):
     d_perp = np.cos(x[1])**2 * 3e-03
 
     if d_perp >= d_par:
-        temp = d_par
-        d_par = d_perp
-        d_perp = temp
+        d_par, d_perp = d_perp, d_par
 
     E_reconst = 0.5 * np.exp(-b_unique * d_perp) * psi_l(0, (b_unique * (d_par - d_perp)))
 
