@@ -1,6 +1,3 @@
-# -*- coding: utf-8 -*-
-from packaging.version import Version
-
 import numpy as np
 
 from dipy.reconst.multi_voxel import multi_voxel_fit
@@ -23,7 +20,7 @@ from dipy.utils.optpkg import optional_package
 from dipy.core.optimize import Optimizer, PositiveDefiniteLeastSquares
 from dipy.data import load_sdp_constraints
 
-cvxpy, have_cvxpy, _ = optional_package("cvxpy")
+cvxpy, have_cvxpy, _ = optional_package("cvxpy", min_version="1.4.1")
 
 
 class MapmriModel(ReconstModel, Cache):
@@ -181,7 +178,7 @@ class MapmriModel(ReconstModel, Cache):
             D=0.7e-3 _[5].
         cvxpy_solver : str, optional
             cvxpy solver name. Optionally optimize the positivity constraint
-            with a particular cvxpy solver. See http://www.cvxpy.org/ for
+            with a particular cvxpy solver. See https://www.cvxpy.org/ for
             details.
             Default: None (cvxpy chooses its own solver)
 
@@ -238,27 +235,25 @@ class MapmriModel(ReconstModel, Cache):
         """
 
         if np.sum(gtab.b0s_mask) == 0:
-            msg = "gtab does not have any b0s, check in the gradient_table "
-            msg += "if b0_threshold needs to be increased."
-            raise ValueError(msg)
+            raise ValueError("gtab does not have any b0s, check in the "
+                             "gradient_table if b0_threshold needs to be "
+                             "increased.")
         self.gtab = gtab
 
         if radial_order < 0 or radial_order % 2:
-            msg = "radial_order must be a positive, even number."
-            raise ValueError(msg)
+            raise ValueError("radial_order must be a positive, even number.")
         self.radial_order = radial_order
 
         self.bval_threshold = bval_threshold
         self.dti_scale_estimation = dti_scale_estimation
 
         if laplacian_regularization:
-            msg = "Laplacian Regularization weighting must be 'GCV', "
-            msg += "a positive float or an array of positive floats."
+            msg = ("Laplacian Regularization weighting must be 'GCV',"
+                   " a positive float or an array of positive floats.")
             if isinstance(laplacian_weighting, str):
                 if not laplacian_weighting == 'GCV':
                     raise ValueError(msg)
-            elif (isinstance(laplacian_weighting, float) or
-                    isinstance(laplacian_weighting, np.ndarray)):
+            elif isinstance(laplacian_weighting, (float, np.ndarray)):
                 if np.sum(laplacian_weighting < 0) > 0:
                     raise ValueError(msg)
             self.laplacian_weighting = laplacian_weighting
@@ -266,24 +261,23 @@ class MapmriModel(ReconstModel, Cache):
 
         if positivity_constraint:
             if not have_cvxpy:
-                raise ValueError('CVXPY package needed to enforce constraints.')
+                raise ImportError('CVXPY package needed to enforce '
+                                  'constraints.')
             if cvxpy_solver is not None:
                 if cvxpy_solver not in cvxpy.installed_solvers():
-                    msg = "Input `cvxpy_solver` was set to %s." % cvxpy_solver
-                    msg += " One of %s" % ', '.join(cvxpy.installed_solvers())
-                    msg += " was expected."
-                    raise ValueError(msg)
+                    installed_solvers = ', '.join(cvxpy.installed_solvers())
+                    raise ValueError(f"Input `cvxpy_solver` was set to"
+                                     f" {cvxpy_solver}. One of"
+                                     f" {installed_solvers} was expected.")
             self.cvxpy_solver = cvxpy_solver
             if global_constraints:
                 if not anisotropic_scaling:
-                    msg = 'Global constraints only available for'
-                    msg += ' anistropic_scaling=True.'
-                    raise ValueError(msg)
+                    raise ValueError('Global constraints only available for'
+                                     ' anistropic_scaling=True.')
                 if radial_order > 10:
                     self.sdp_constraints = load_sdp_constraints('hermite', 10)
-                    msg = 'Global constraints are currently supported for'
-                    msg += ' radial_order <= 10.'
-                    warn(msg)
+                    warn('Global constraints are currently supported for'
+                         ' radial_order <= 10.')
                 else:
                     self.sdp_constraints = load_sdp_constraints('hermite',
                                                                 radial_order)
@@ -420,10 +414,7 @@ class MapmriModel(ReconstModel, Cache):
                 coef = self.sdp.solve(M, data_norm, solver=self.cvxpy_solver)
             else:
                 c = cvxpy.Variable(M.shape[1])
-                if Version(cvxpy.__version__) < Version('1.1'):
-                    design_matrix = cvxpy.Constant(M) * c
-                else:
-                    design_matrix = cvxpy.Constant(M) @ c
+                design_matrix = cvxpy.Constant(M) @ c
                 # workaround for the bug on cvxpy 1.0.15 when lopt = 0
                 # See https://github.com/cvxgrp/cvxpy/issues/672
                 if not lopt:
@@ -455,12 +446,7 @@ class MapmriModel(ReconstModel, Cache):
                         K = K_dependent * self.pos_K_independent
 
                 M0 = M[self.gtab.b0s_mask, :]
-                if Version(cvxpy.__version__) < Version('1.1'):
-                    constraints = [(M0[0] * c) == 1,
-                                   (K * c) >= -0.1]
-                else:
-                    constraints = [(M0[0] @ c) == 1,
-                                   (K @ c) >= -0.1]
+                constraints = [(M0[0] @ c) == 1, (K @ c) >= -0.1]
                 prob = cvxpy.Problem(objective, constraints)
                 try:
                     prob.solve(solver=self.cvxpy_solver)
@@ -594,9 +580,8 @@ class MapmriFit(ReconstFit):
         NeuroImage (2016).
         """
         if self.model.anisotropic_scaling:
-            msg = 'odf in spherical harmonics not yet implemented for '
-            msg += 'anisotropic implementation'
-            raise ValueError(msg)
+            raise ValueError('odf in spherical harmonics not yet implemented '
+                             'for anisotropic implementation')
         I = self.model.cache_get('ODF_sh_matrix', key=(self.radial_order, s))
 
         if I is None:
@@ -843,13 +828,11 @@ class MapmriFit(ReconstFit):
         NeuroImage 2015, in press.
         """
         if self.model.bval_threshold > 2000.:
-            msg = 'model bval_threshold must be lower than 2000 for the '
-            msg += 'non_Gaussianity to be physically meaningful [2].'
-            warn(msg)
+            warn('model bval_threshold must be lower than 2000 for the '
+                 'non_Gaussianity to be physically meaningful [2].')
         if not self.model.anisotropic_scaling:
-            msg = 'Parallel non-Gaussianity is not defined using '
-            msg += 'isotropic scaling.'
-            raise ValueError(msg)
+            raise ValueError('Parallel non-Gaussianity is not defined using '
+                             'isotropic scaling.')
 
         coef = self._mapmri_coef
         return np.sqrt(1 - coef[0] ** 2 / np.sum(coef ** 2))
@@ -871,13 +854,11 @@ class MapmriFit(ReconstFit):
         NeuroImage 2015, in press.
         """
         if self.model.bval_threshold > 2000.:
-            msg = 'Model bval_threshold must be lower than 2000 for the '
-            msg += 'non_Gaussianity to be physically meaningful [2].'
-            warn(msg)
+            warn('Model bval_threshold must be lower than 2000 for the '
+                 'non_Gaussianity to be physically meaningful [2].')
         if not self.model.anisotropic_scaling:
-            msg = 'Parallel non-Gaussianity is not defined using '
-            msg += 'isotropic scaling.'
-            raise ValueError(msg)
+            raise ValueError('Parallel non-Gaussianity is not defined using '
+                             'isotropic scaling.')
 
         ind_mat = self.model.ind_mat
         coef = self._mapmri_coef
@@ -911,13 +892,11 @@ class MapmriFit(ReconstFit):
         NeuroImage 2015, in press.
         """
         if self.model.bval_threshold > 2000.:
-            msg = 'model bval_threshold must be lower than 2000 for the '
-            msg += 'non_Gaussianity to be physically meaningful [2].'
-            warn(msg)
+            warn('model bval_threshold must be lower than 2000 for the '
+                 'non_Gaussianity to be physically meaningful [2].')
         if not self.model.anisotropic_scaling:
-            msg = 'Parallel non-Gaussianity is not defined using '
-            msg += 'isotropic scaling.'
-            raise ValueError(msg)
+            raise ValueError('Parallel non-Gaussianity is not defined using '
+                             'isotropic scaling.')
 
         ind_mat = self.model.ind_mat
         coef = self._mapmri_coef
