@@ -17,7 +17,7 @@ from dipy.reconst.utils import _roi_in_volume, _mask_from_roi
 from dipy.sims.voxel import single_tensor
 
 from dipy.utils.optpkg import optional_package
-cvxpy, have_cvxpy, _ = optional_package("cvxpy")
+cvxpy, have_cvxpy, _ = optional_package("cvxpy", min_version="1.4.1")
 
 SH_CONST = .5 / np.sqrt(np.pi)
 
@@ -58,7 +58,7 @@ def multi_tissue_basis(gtab, sh_order, iso_comp):
     return B, m, n
 
 
-class MultiShellResponse(object):
+class MultiShellResponse:
 
     def __init__(self, response, sh_order, shells, S0=None):
         """ Estimate Multi Shell response function for multiple tissues and
@@ -146,7 +146,7 @@ def _basic_delta(iso, m, n, theta, phi):
 class MultiShellDeconvModel(shm.SphHarmModel):
 
     def __init__(self, gtab, response, reg_sphere=default_sphere,
-                 sh_order=8, iso=2):
+                 sh_order=8, iso=2, tol=20):
         r"""
         Multi-Shell Multi-Tissue Constrained Spherical Deconvolution
         (MSMT-CSD) [1]_. This method extends the CSD model proposed in [2]_ by
@@ -186,6 +186,8 @@ class MultiShellDeconvModel(shm.SphHarmModel):
             Number of tissue compartments for running the MSMT-CSD. Minimum
             number of compartments required is 2.
             Default: 2
+        tol : int, optional
+            Tolerance gap for b-values clustering.
 
         References
         ----------
@@ -206,7 +208,7 @@ class MultiShellDeconvModel(shm.SphHarmModel):
         super(MultiShellDeconvModel, self).__init__(gtab)
 
         if not isinstance(response, MultiShellResponse):
-            bvals = unique_bvals_tolerance(gtab.bvals, tol=20)
+            bvals = unique_bvals_tolerance(gtab.bvals, tol=tol)
             if iso > 2:
                 msg = """Too many compartments for this kind of response
                 input. It must be two tissue compartments."""
@@ -380,17 +382,9 @@ def solve_qp(P, Q, G, H):
     """
     x = cvxpy.Variable(Q.shape[0])
     P = cvxpy.Constant(P)
-    if Version(cvxpy.__version__) >= Version('1.3'):
-        objective = cvxpy.Minimize(0.5 * cvxpy.quad_form(x, P, True) + Q @ x)
-        constraints = [G @ x <= H]
-    elif Version(cvxpy.__version__) >= Version('1.2'):
-        P_psd = cvxpy.atoms.affine.wraps.psd_wrap(P)
-        objective = cvxpy.Minimize(0.5 * cvxpy.quad_form(x, P_psd) + Q @ x)
-        constraints = [G @ x <= H]
-    elif Version(cvxpy.__version__) < Version('1.2'):
-        msg = """Dipy does not support versions of cvxpy below 1.2."""
-        raise ValueError(msg)
-    
+    objective = cvxpy.Minimize(0.5 * cvxpy.quad_form(x, P, True) + Q @ x)
+    constraints = [G @ x <= H]
+
     # setting up the problem
     prob = cvxpy.Problem(objective, constraints)
     try:
@@ -403,7 +397,7 @@ def solve_qp(P, Q, G, H):
     return opt
 
 
-class QpFitter(object):
+class QpFitter:
 
     def __init__(self, X, reg):
         r"""
@@ -435,7 +429,7 @@ class QpFitter(object):
 
 
 def multi_shell_fiber_response(sh_order, bvals, wm_rf, gm_rf, csf_rf,
-                               sphere=None, tol=20):
+                               sphere=None, tol=20, btens=None):
     """Fiber response function estimation for multi-shell data.
 
     Parameters
@@ -453,6 +447,19 @@ def multi_shell_fiber_response(sh_order, bvals, wm_rf, gm_rf, csf_rf,
         Response function of the CSF tissue, for each bvals.
     sphere : `dipy.core.Sphere` instance, optional
         Sphere where the signal will be evaluated.
+    tol : int, optional
+        Tolerance gap for b-values clustering.
+    btens : can be any of two options, optional
+
+        1. an array of strings of shape (N,) specifying
+           encoding tensor shape associated with all unique b-values
+           separately. N corresponds to the number of unique b-values,
+           including the b0. Options for elements in array: 'LTE',
+           'PTE', 'STE', 'CTE' corresponding to linear, planar, spherical, and
+           "cigar-shaped" tensor encoding.
+        2. an array of shape (N,3,3) specifying the b-tensor of each unique
+           b-values exactly. N corresponds to the number of unique b-values,
+           including the b0.
 
     Returns
     -------
@@ -463,6 +470,11 @@ def multi_shell_fiber_response(sh_order, bvals, wm_rf, gm_rf, csf_rf,
     rcond_value = None if NUMPY_1_14_PLUS else -1
 
     bvals = np.array(bvals, copy=True)
+    if btens is None:
+        btens = np.repeat(["LTE"], len(bvals))
+    elif len(btens) != len(bvals):
+        msg = """bvals and btens parameters must have the same dimension."""
+        raise ValueError(msg)
     evecs = np.zeros((3, 3))
     z = np.array([0, 0, 1.])
     evecs[:, 0] = z
@@ -483,7 +495,7 @@ def multi_shell_fiber_response(sh_order, bvals, wm_rf, gm_rf, csf_rf,
     response = np.empty([len(bvals), len(n) + 2])
 
     if bvals[0] < tol:
-        gtab = GradientTable(big_sphere.vertices * 0)
+        gtab = GradientTable(big_sphere.vertices * 0, btens=btens[0])
         wm_response = single_tensor(gtab, wm_rf[0, 3], wm_rf[0, :3], evecs,
                                     snr=None)
         response[0, 2:] = np.linalg.lstsq(B, wm_response, rcond=rcond_value)[0]
@@ -492,7 +504,8 @@ def multi_shell_fiber_response(sh_order, bvals, wm_rf, gm_rf, csf_rf,
         response[0, 0] = csf_rf[0, 3] / A
 
         for i, bvalue in enumerate(bvals[1:]):
-            gtab = GradientTable(big_sphere.vertices * bvalue)
+            gtab = GradientTable(big_sphere.vertices * bvalue,
+                                 btens=btens[i + 1])
             wm_response = single_tensor(gtab, wm_rf[i, 3], wm_rf[i, :3], evecs,
                                         snr=None)
             response[i+1, 2:] = np.linalg.lstsq(B, wm_response,
@@ -506,7 +519,8 @@ def multi_shell_fiber_response(sh_order, bvals, wm_rf, gm_rf, csf_rf,
     else:
         warnings.warn("""No b0 given. Proceeding either way.""", UserWarning)
         for i, bvalue in enumerate(bvals):
-            gtab = GradientTable(big_sphere.vertices * bvalue)
+            gtab = GradientTable(big_sphere.vertices * bvalue,
+                                 btens=btens[i])
             wm_response = single_tensor(gtab, wm_rf[i, 3], wm_rf[i, :3], evecs,
                                         snr=None)
             response[i, 2:] = np.linalg.lstsq(B, wm_response,
@@ -739,6 +753,8 @@ def auto_response_msmt(gtab, data, tol=20, roi_center=None, roi_radii=10,
     gtab : GradientTable
     data : ndarray
         diffusion data
+    tol : int, optional
+        Tolerance gap for b-values clustering.
     roi_center : array-like, (3,)
         Center of ROI in data. If center is None, it is assumed that it is
         the center of the volume with shape `data.shape[:3]`.
