@@ -645,7 +645,7 @@ def order_from_ncoef(ncoef, full_basis=False):
 
     # Solve the quadratic equation derived from :
     # ncoef = (sh_order + 2) * (sh_order + 1) / 2
-    return int(-3 + np.sqrt(9 - 4 * (2-2*ncoef)))/2
+    return -1 + int(np.sqrt(9 - 4 * (2-2*ncoef))//2)
 
 
 def smooth_pinv(B, L):
@@ -657,7 +657,7 @@ def smooth_pinv(B, L):
     ----------
     B : array_like (n, m)
         Matrix to be inverted
-    L : array_like (n,)
+    L : array_like (m,)
 
     Returns
     -------
@@ -1012,13 +1012,13 @@ def lcr_matrix(H):
     """Returns a matrix for computing leveraged, centered residuals from data
 
     if r = (d-Hd), the leveraged centered residuals are lcr = (r/l)-mean(r/l)
-    ruturns the matrix R, such lcr = Rd
+    returns the matrix R, such that lcr = Rd
 
     """
     if H.ndim != 2 or H.shape[0] != H.shape[1]:
         raise ValueError('H should be a square matrix')
 
-    leverages = np.sqrt(1 - H.diagonal(), where=H.diagonal() <= 1)
+    leverages = np.sqrt(1 - H.diagonal(), where=H.diagonal() < 1)
     leverages = leverages[:, None]
     R = (np.eye(len(H)) - H) / leverages
     return R - R.mean(0)
@@ -1067,7 +1067,7 @@ def bootstrap_data_voxel(data, H, R, permute=None):
     return boot_data
 
 
-class ResidualBootstrapWrapper(object):
+class ResidualBootstrapWrapper:
     """Returns a residual bootstrap sample of the signal_object when indexed
 
     Wraps a signal_object, this signal object can be an interpolator. When
@@ -1358,10 +1358,10 @@ def calculate_max_order(n_coeffs, full_basis=False):
             return int(L1)
 
     # Otherwise, the input didn't make sense:
-    raise ValueError("The input to ``calculate_max_order`` was ",
-                     "%s, but that is not a valid number" % n_coeffs,
-                     "of coefficients for a spherical harmonics ",
-                     "basis set.")
+    raise ValueError(f"The input to ``calculate_max_order`` was"
+                     f" {n_coeffs}, but that is not a valid number"
+                     f" of coefficients for a spherical harmonics"
+                     f" basis set.")
 
 
 def anisotropic_power(sh_coeffs, norm_factor=0.00001, power=2,
