@@ -1,7 +1,5 @@
-
 from warnings import warn
 from math import factorial
-from packaging.version import Version
 
 import numpy as np
 
@@ -14,7 +12,7 @@ from dipy.core.geometry import cart2sphere
 
 from dipy.utils.optpkg import optional_package
 
-cvxpy, have_cvxpy, _ = optional_package("cvxpy")
+cvxpy, have_cvxpy, _ = optional_package("cvxpy", min_version="1.4.1")
 
 
 class ShoreModel(Cache):
@@ -62,7 +60,7 @@ class ShoreModel(Cache):
 
     Notes
     -----
-    The implementation of SHORE depends on CVXPY (http://www.cvxpy.org/).
+    The implementation of SHORE depends on CVXPY (https://www.cvxpy.org/).
     """
 
     def __init__(self,
@@ -127,7 +125,7 @@ class ShoreModel(Cache):
             millimeters. By default 20e-03 mm.
         cvxpy_solver : str, optional
             cvxpy solver name. Optionally optimize the positivity constraint
-            with a particular cvxpy solver. See http://www.cvxpy.org/ for
+            with a particular cvxpy solver. See https://www.cvxpy.org/ for
             details.
             Default: None (cvxpy chooses its own solver)
 
@@ -199,7 +197,7 @@ class ShoreModel(Cache):
             if not have_cvxpy:
                 msg = "cvxpy must be installed for positive_constraint or "
                 msg += "constraint_e0."
-                raise ValueError(msg)
+                raise ImportError(msg)
             if cvxpy_solver is not None:
                 if cvxpy_solver not in cvxpy.installed_solvers():
                     msg = "Input `cvxpy_solver` was set to %s." % cvxpy_solver
@@ -250,10 +248,7 @@ class ShoreModel(Cache):
             M0 = M[self.gtab.b0s_mask, :]
 
             c = cvxpy.Variable(M.shape[1])
-            if Version(cvxpy.__version__) < Version('1.1'):
-                design_matrix = cvxpy.Constant(M) * c
-            else:
-                design_matrix = cvxpy.Constant(M) @ c
+            design_matrix = cvxpy.Constant(M) @ c
             objective = cvxpy.Minimize(
                 cvxpy.sum_squares(design_matrix - data_norm) +
                 self.lambdaN * cvxpy.quad_form(c, Nshore) +
@@ -261,10 +256,7 @@ class ShoreModel(Cache):
             )
 
             if not self.positive_constraint:
-                if Version(cvxpy.__version__) < Version('1.1'):
-                    constraints = [M0[0] * c == 1]
-                else:
-                    constraints = [M0[0] @ c == 1]
+                constraints = [M0[0] @ c == 1]
             else:
                 lg = int(np.floor(self.pos_grid ** 3 / 2))
                 v, t = create_rspace(self.pos_grid, self.pos_radius)
@@ -276,10 +268,7 @@ class ShoreModel(Cache):
                     self.cache_set(
                         'shore_matrix_positive_constraint',
                         (self.pos_grid, self.pos_radius), psi)
-                if Version(cvxpy.__version__) < Version('1.1'):
-                    constraints = [(M0[0] * c) == 1., (psi * c) >= 1e-3]
-                else:
-                    constraints = [(M0[0] @ c) == 1., (psi @ c) >= 1e-3]
+                constraints = [(M0[0] @ c) == 1., (psi @ c) >= 1e-3]
             prob = cvxpy.Problem(objective, constraints)
             try:
                 prob.solve(solver=self.cvxpy_solver)
