@@ -2,6 +2,7 @@
 
 import numpy as np
 import random
+
 import dipy.reconst.dki as dki
 import dipy.reconst.dti as dti
 from numpy.testing import (assert_array_almost_equal, assert_array_equal,
@@ -21,8 +22,9 @@ from dipy.core.sphere import Sphere
 from dipy.data import default_sphere
 from dipy.core.geometry import sphere2cart
 from dipy.utils.optpkg import optional_package
+from dipy.utils.tripwire import TripWireError
 
-_, have_cvxpy, _ = optional_package("cvxpy")
+cvxpy, have_cvxpy, _ = optional_package("cvxpy", min_version="1.4.1")
 
 fimg, fbvals, fbvecs = get_fnames('small_64D')
 bvals, bvecs = read_bvals_bvecs(fbvals, fbvecs)
@@ -122,20 +124,22 @@ def test_dki_fits():
 
     if have_cvxpy:
         # CLS fitting
-        dki_clsM = dki.DiffusionKurtosisModel(gtab_2s, fit_method="CLS")
+        dki_clsM = dki.DiffusionKurtosisModel(
+            gtab_2s, fit_method="CLS", cvxpy_solver=cvxpy.CLARABEL)
         dki_clsF = dki_clsM.fit(signal_cross)
 
         assert_array_almost_equal(dki_clsF.model_params, crossing_ref)
 
         # CWLS fitting
-        dki_cwlsM = dki.DiffusionKurtosisModel(gtab_2s, fit_method="CWLS")
+        dki_cwlsM = dki.DiffusionKurtosisModel(
+            gtab_2s, fit_method="CWLS", cvxpy_solver=cvxpy.CLARABEL)
         dki_cwlsF = dki_cwlsM.fit(signal_cross)
 
         assert_array_almost_equal(dki_cwlsF.model_params, crossing_ref)
     else:
-        assert_raises(ValueError, dki.DiffusionKurtosisModel,
+        assert_raises(TripWireError, dki.DiffusionKurtosisModel,
                       gtab_2s, fit_method="CLS")
-        assert_raises(ValueError, dki.DiffusionKurtosisModel,
+        assert_raises(TripWireError, dki.DiffusionKurtosisModel,
                       gtab_2s, fit_method="CWLS")
 
     # NLS fitting
