@@ -1,5 +1,7 @@
 """Testing DTI."""
 
+import warnings
+
 import numpy as np
 import numpy.testing as npt
 
@@ -7,7 +9,7 @@ import scipy.optimize as opt
 
 import dipy.reconst.dti as dti
 from dipy.io.gradients import read_bvals_bvecs
-from dipy.reconst.dti import (axial_diffusivity, color_fa,
+from dipy.reconst.dti import (ols_resort_msg, axial_diffusivity, color_fa,
                               fractional_anisotropy, from_lower_triangular,
                               geodesic_anisotropy, lower_triangular,
                               mean_diffusivity, radial_diffusivity,
@@ -24,6 +26,8 @@ import dipy.core.sphere as dps
 
 from dipy.sims.voxel import single_tensor
 
+from dipy.testing.decorators import set_random_number_generator
+
 
 def test_roll_evals():
     # Just making sure this never passes through
@@ -31,9 +35,10 @@ def test_roll_evals():
     npt.assert_raises(ValueError, dti._roll_evals, weird_evals)
 
 
-def test_tensor_algebra():
+@set_random_number_generator()
+def test_tensor_algebra(rng):
     # Test that the computation of tensor determinant and norm is correct
-    test_arr = np.random.rand(10, 3, 3)
+    test_arr = rng.random((10, 3, 3))
     t_det = dti.determinant(test_arr)
     t_norm = dti.norm(test_arr)
     for i, x in enumerate(test_arr):
@@ -169,8 +174,8 @@ def test_tensor_model():
         model = dti.TensorModel(gtab, fit_method=lambda *args, **kwargs: 42)
         fit = model.fit_method()
     except Exception as exc:
-        assert False, "TensorModel should accept custom fit methods: %s" % exc
-    assert fit == 42, "Custom fit method for TensorModel returned %s." % fit
+        assert False, f"TensorModel should accept custom fit methods: {exc}"
+    assert fit == 42, f"Custom fit method for TensorModel returned {fit}."
 
     # Test multi-voxel data
     data = np.zeros((3, Y.shape[1]))
@@ -511,37 +516,56 @@ def test_mask():
                                     dtifit.S0_hat[0, 0, 0])
 
 
-def test_nnls_jacobian_fucn():
+@set_random_number_generator()
+def test_nnls_jacobian_func(rng):
     b0 = 1000.
     bval, bvecs = read_bvals_bvecs(*get_fnames('55dir_grad'))
     gtab = grad.gradient_table(bval, bvecs)
     B = bval[1]
 
     # Scale the eigenvalues and tensor by the B value so the units match
-    D = np.array([1., 1., 1., 0., 0., 1., -np.log(b0) * B]) / B
+    D_orig = np.array([1., 1., 1., 0., 0., 1., -np.log(b0) * B]) / B
 
     # Design Matrix
     X = dti.design_matrix(gtab)
 
     # Signals
-    Y = np.exp(np.dot(X, D))
+    Y = np.exp(np.dot(X, D_orig))
+    scale = 10
+    error = rng.normal(scale=scale, size=Y.shape)
+    Y = Y + error
 
-    # Test Jacobian at D
-    args = [X, Y]
-    analytical = dti._nlls_jacobian_func(D, *args)
-    for i in range(len(X)):
-        args = [X[i], Y[i]]
-        approx = opt.approx_fprime(D, dti._nlls_err_func, 1e-8, *args)
-        assert np.allclose(approx, analytical[i])
+    # although sigma and gmm gradients seem correct from inspection,
+    # they are not accurate enough to pass the tests, leaving out
+    # for weighting in [None, "sigma", "gmm"]:
+    for weighting in [None]:
+        nlls = dti._NllsHelper()
 
-    # Test Jacobian at zero
-    D = np.zeros_like(D)
-    args = [X, Y]
-    analytical = dti._nlls_jacobian_func(D, *args)
-    for i in range(len(X)):
-        args = [X[i], Y[i]]
-        approx = opt.approx_fprime(D, dti._nlls_err_func, 1e-8, *args)
-        assert np.allclose(approx, analytical[i])
+        for D in [D_orig, np.zeros_like(D_orig)]:
+
+            if weighting is None:
+                sigma = None
+            if weighting == "sigma":
+                sigma = 1.0 / np.abs(error)  # use residuals as estimate
+            if weighting == "gmm":
+                sigma = 1.4826 * np.median(np.abs(error - np.median(error)))
+
+            # Test Jacobian at D
+            args = [D, X, Y, weighting, sigma]
+            # NOTE: call 'err_func' first, to set internal stuff in the class
+            nlls.err_func(*args)
+            # NOTE: cal 'jabobian_func' with D (ensure cached vars are for D)
+            analytical = nlls.jacobian_func(*args)
+            for i in range(len(X)):
+                if weighting is None:
+                    args = [X[i], Y[i], weighting, sigma]
+                if weighting == "sigma":
+                    args = [X[i], Y[i], weighting, sigma[i]]
+                if weighting == "gmm":
+                    args = [X[i], Y[i], weighting, sigma]
+                approx = opt.approx_fprime(D, nlls.err_func, 1e-8, *args)
+
+                assert np.allclose(approx, analytical[i])
 
 
 def test_nlls_fit_tensor():
@@ -585,7 +609,8 @@ def test_nlls_fit_tensor():
     npt.assert_almost_equal(tensor_est.md[0], md)
 
     # Using the gmm weighting scheme:
-    tensor_model = dti.TensorModel(gtab, fit_method='NLLS', weighting='gmm')
+    tensor_model = dti.TensorModel(gtab, fit_method='NLLS', weighting='gmm',
+                                   sigma=1)
     tensor_est = tensor_model.fit(Y)
     npt.assert_equal(tensor_est.shape, Y.shape[:-1])
     npt.assert_array_almost_equal(tensor_est.evals[0], evals)
@@ -623,6 +648,22 @@ def test_nlls_fit_tensor():
     tmf = npt.assert_warns(UserWarning, tensor_model.fit, Y_less)
     npt.assert_equal(tmf[0].S0_hat, np.nan)
 
+    # Test sigma with an array
+    sigma = np.ones(Y_less.shape[-1])
+    tensor_model = dti.TensorModel(gtab_less, fit_method='NLLS',
+                                   weighting='sigma', sigma=sigma)
+    with warnings.catch_warnings():
+        warnings.filterwarnings(
+            "ignore", message=ols_resort_msg,
+            category=UserWarning)
+        tmf = tensor_model.fit(Y_less)
+
+    # Test sigma with an array of wrong size
+    sigma = np.ones(Y_less.shape[-1] + 10)
+    tensor_model = dti.TensorModel(gtab_less, fit_method='NLLS',
+                                   weighting='sigma', sigma=sigma)
+    tmf = npt.assert_raises(ValueError, tensor_model.fit, Y_less)
+
 
 def test_restore():
     """
