@@ -1,4 +1,3 @@
-
 from functools import reduce
 
 import numpy as np
@@ -6,6 +5,7 @@ import numpy.testing as npt
 
 from dipy.reconst.multi_voxel import _squash, multi_voxel_fit, CallableArray
 from dipy.core.sphere import unit_icosahedron
+from dipy.testing.decorators import set_random_number_generator
 
 
 def test_squash():
@@ -37,9 +37,13 @@ def test_squash():
     # Check dtypes for arrays and scalars
     arr_arr = np.zeros((2,), dtype=object)
     scalar_arr = np.zeros((2,), dtype=object)
-    numeric_types = sum(
-        [np.sctypes[t] for t in ('int', 'uint', 'float', 'complex')],
-        [bool])
+    numeric_types = [getattr(np, dtype) for dtype in (
+        'int8', 'byte', 'int16', 'short', 'int32', 'intc', 'int_', 'int64',
+        'longlong', 'uint8', 'ubyte', 'uint16', 'ushort', 'uint32', 'uintc',
+        'uint', 'uint64', 'ulonglong', 'float16', 'half', 'float32', 'single',
+        'float64', 'double', 'float96', 'float128', 'longdouble', 'complex64',
+        'csingle', 'complex128', 'cdouble', 'complex192', 'complex256',
+        'clongdouble') if hasattr(np, dtype)] + [bool]
     for dt0 in numeric_types:
         arr_arr[0] = np.zeros((3,), dtype=dt0)
         scalar_arr[0] = dt0(0)
@@ -100,9 +104,10 @@ def test_CallableArray():
     npt.assert_array_equal(callarray(4), expected)
 
 
-def test_multi_voxel_fit():
+@set_random_number_generator()
+def test_multi_voxel_fit(rng):
 
-    class SillyModel(object):
+    class SillyModel:
 
         @multi_voxel_fit
         def fit(self, data, mask=None):
@@ -111,7 +116,7 @@ def test_multi_voxel_fit():
         def predict(self, S0):
             return np.ones(10) * S0
 
-    class SillyFit(object):
+    class SillyFit:
 
         def __init__(self, model, data):
             self.model = model
@@ -124,7 +129,7 @@ def test_multi_voxel_fit():
 
         @property
         def directions(self):
-            n = np.random.randint(0, 10)
+            n = rng.integers(0, 10)
             return np.zeros((n, 3))
 
         def predict(self, S0):
