@@ -11,6 +11,7 @@ import dipy.segment.featurespeed as dipysfeature
 import dipy.segment.metricspeed as dipysmetric
 from dipy.segment.clustering_algorithms import quickbundles
 import dipy.tracking.streamline as streamline_utils
+from dipy.testing.decorators import set_random_number_generator
 
 
 dtype = "float32"
@@ -63,15 +64,20 @@ def test_quickbundles_shape_incompatibility():
                         list(itertools.chain(*clusters2)))
 
 
-def test_quickbundles_2D():
+@set_random_number_generator(7)
+def test_quickbundles_2D(rng):
     # Test quickbundles clustering using 2D points and the Eulidean metric.
-    rng = np.random.RandomState(42)
     data = []
-    data += [rng.randn(1, 2) + np.array([0, 0]) for _ in range(1)]
-    data += [rng.randn(1, 2) + np.array([10, 10]) for _ in range(2)]
-    data += [rng.randn(1, 2) + np.array([-10, 10]) for _ in range(3)]
-    data += [rng.randn(1, 2) + np.array([10, -10]) for _ in range(4)]
-    data += [rng.randn(1, 2) + np.array([-10, -10]) for _ in range(5)]
+    data += \
+        [rng.standard_normal((1, 2)) + np.array([0, 0]) for _ in range(1)]
+    data += \
+        [rng.standard_normal((1, 2)) + np.array([10, 10]) for _ in range(2)]
+    data += \
+        [rng.standard_normal((1, 2)) + np.array([-10, 10]) for _ in range(3)]
+    data += \
+        [rng.standard_normal((1, 2)) + np.array([10, -10]) for _ in range(4)]
+    data += \
+        [rng.standard_normal((1, 2)) + np.array([-10, -10]) for _ in range(5)]
     data = np.array(data, dtype=dtype)
 
     clusters_truth = [[0], [1, 2], [3, 4, 5],
