@@ -1,11 +1,9 @@
-
 import os
 import numpy as np
 from scipy.spatial import cKDTree
 from scipy.ndimage import map_coordinates
 from scipy.spatial.distance import mahalanobis
 
-from dipy.utils.optpkg import optional_package
 from dipy.io.utils import save_buan_profiles_hdf5
 from dipy.segment.clustering import QuickBundles
 from dipy.segment.metricspeed import AveragePointwiseEuclideanMetric
@@ -14,9 +12,6 @@ from dipy.tracking.streamline import (set_number_of_points,
                                       orient_by_streamline,
                                       Streamlines)
 
-pd, have_pd, _ = optional_package("pandas")
-_, have_tables, _ = optional_package("tables")
-
 
 def peak_values(
         bundle, peaks, dt, pname, bname, subject, group_id, ind, dir_name):
@@ -120,7 +115,13 @@ def assignment_map(target_bundle, model_bundle, no_disks):
     model_bundle : streamlines
         atlas bundle used as reference
     no_disks : integer, optional
-        Number of disks used for dividing bundle into disks. (Default 100)
+        Number of disks used for dividing bundle into disks.
+
+    Returns
+    -------
+    indx : ndarray
+        Assignment map of the target bundle streamline point indices to the
+        model bundle centroid points.
 
     References
     ----------
