@@ -42,7 +42,4 @@ def test_fbc():
         fbc.get_points_rfbc_thresholded(0, emphasis=0.01)
 
     # check mean RFBC against tested value
-    npt.assert_almost_equal(np.mean(rfbc_orig), 1.0500466494329224)
-
-if __name__ == '__main__':
-    npt.run_module_suite()
+    npt.assert_almost_equal(np.mean(rfbc_orig), 1.0500466494329224, decimal=4)
