@@ -1,13 +1,15 @@
 # Init file for visualization package
 import warnings
 
+from dipy.viz.horizon.app import horizon
+
 from dipy.utils.optpkg import optional_package
 # Allow import, but disable doctests if we don't have fury
 fury, has_fury, _ = optional_package(
     'fury',
-    "You do not have FURY installed. Some visualization functions"
+    trip_msg="You do not have FURY installed. Some visualization functions"
     "might not work for you. For installation instructions, please visit: "
-    "https://fury.gl/")
+    "https://fury.gl/", min_version="0.9.0")
 
 
 if has_fury:
@@ -26,9 +28,9 @@ else:
 # We make the visualization requirements optional imports:
 _, has_mpl, _ = optional_package(
     'matplotlib',
-    "You do not have Matplotlib installed. Some visualization functions"
-    "might not work for you. For installation instructions, please visit: "
-    "https://matplotlib.org/")
+    trip_msg="You do not have Matplotlib installed. Some visualization "
+    "functions might not work for you. For installation instructions, "
+    "please visit: https://matplotlib.org/")
 
 if has_mpl:
     from . import projections
