@@ -1,5 +1,6 @@
 from dipy.viz.horizon.tab.base import (HorizonTab, TabManager, build_label,
-                                       color_double_slider,
+                                       build_slider, build_checkbox,
+                                       build_switcher, color_double_slider,
                                        color_single_slider)
 from dipy.viz.horizon.tab.cluster import ClustersTab
 from dipy.viz.horizon.tab.peak import PeaksTab
@@ -8,4 +9,6 @@ from dipy.viz.horizon.tab.slice import SlicesTab
 
 __all__ = [
     'HorizonTab', 'TabManager', 'ClustersTab', 'PeaksTab', 'ROIsTab',
-    'SlicesTab', 'build_label', 'color_double_slider', 'color_single_slider']
+    'SlicesTab', 'build_label', 'build_slider', 'build_checkbox',
+    'build_switcher',
+    'color_double_slider', 'color_single_slider']
