@@ -9,7 +9,7 @@ import numpy as np
 import scipy.interpolate as interp
 from dipy.utils.optpkg import optional_package
 import dipy.core.geometry as geo
-from dipy.testing import doctest_skip_parser
+from dipy.testing.decorators import doctest_skip_parser
 
 matplotlib, has_mpl, setup_module = optional_package("matplotlib")
 plt, _, _ = optional_package("matplotlib.pyplot")
@@ -53,8 +53,8 @@ def sph_project(vertices, val, ax=None, vmin=None, vmax=None, cmap=None,
 
     Examples
     --------
-    >>> from dipy.data import get_sphere
-    >>> verts = get_sphere('symmetric724').vertices
+    >>> from dipy.data import default_sphere
+    >>> verts = default_sphere.vertices
     >>> ax = sph_project(verts.T, np.random.rand(len(verts.T))) # skip if not has_basemap
     """
     if ax is None:
@@ -76,13 +76,13 @@ def sph_project(vertices, val, ax=None, vmin=None, vmax=None, cmap=None,
 
     # Rotate the coordinate system so that you are looking from the north pole:
     verts_rot = np.array(
-        np.dot(np.matrix([[0, 0, -1], [0, 1, 0], [1, 0, 0]]), vertices))
+        np.dot(np.array([[0, 0, -1], [0, 1, 0], [1, 0, 0]]), vertices))
 
     # To get the orthographic projection, when the first coordinate is
     # positive:
     neg_idx = np.where(verts_rot[0] > 0)
 
-    # rotate the entire bvector around to point in the other direction:
+    # rotate the entire b-vector around to point in the other direction:
     verts_rot[:, neg_idx] *= -1
 
     _, theta, phi = geo.cart2sphere(verts_rot[0], verts_rot[1], verts_rot[2])
@@ -109,7 +109,7 @@ def sph_project(vertices, val, ax=None, vmin=None, vmax=None, cmap=None,
 
         r = (val - my_min) / float(my_max - my_min)
 
-        # Enforce the maximum and minumum boundaries, if there are values
+        # Enforce the maximum and minimum boundaries, if there are values
         # outside those boundaries:
         r[r < 0] = 0
         r[r > 1] = 1
