@@ -1,11 +1,10 @@
 import os
 import sys
-import shutil
 
 import numpy as np
 import logging
 import importlib
-from inspect import getmembers, isfunction, getfullargspec
+from inspect import getmembers, isfunction
 from dipy.io.image import load_nifti, save_nifti
 from dipy.workflows.workflow import Workflow
 
@@ -134,7 +133,9 @@ class FetchFlow(Workflow):
                                for name, func in getmembers(fetcher_module,
                                                             isfunction)
                                if name.lower().startswith("fetch_") and
-                               func is not fetcher_module.fetch_data])
+                               func is not fetcher_module.fetch_data
+                               if name.lower() not in ['fetch_hbn',
+                                                       'fetch_hcp']])
 
         return available_data
 
