@@ -1,4 +1,3 @@
-
 import logging
 import numpy as np
 import os
@@ -24,19 +23,9 @@ from dipy.stats.analysis import anatomical_measures
 from dipy.stats.analysis import peak_values
 
 pd, have_pd, _ = optional_package("pandas")
-smf, have_smf, _ = optional_package("statsmodels")
-tables, have_tables, _ = optional_package("tables")
+smf, have_smf, _ = optional_package("statsmodels.formula.api")
 matplt, have_matplotlib, _ = optional_package("matplotlib")
-
-if have_pd:
-    import pandas as pd
-
-if have_smf:
-    import statsmodels.formula.api as smf
-
-if have_matplotlib:
-    import matplotlib as matplt
-    import matplotlib.pyplot as plt
+plt, have_plt, _ = optional_package("matplotlib.pyplot")
 
 
 class SNRinCCFlow(Workflow):
@@ -97,7 +86,7 @@ class SNRinCCFlow(Workflow):
             elif np.ndim(data) == 3:
                 CC_box = np.zeros_like(data)
             else:
-                raise IOError('DWI data has invalid dimensions')
+                raise OSError('DWI data has invalid dimensions')
 
             mins, maxs = bounding_box(mask)
             mins = np.array(mins)
@@ -111,7 +100,7 @@ class SNRinCCFlow(Workflow):
                    bounds_min[2]:bounds_max[2]] = 1
 
             if len(bbox_threshold) != 6:
-                raise IOError('bbox_threshold should have 6 float values')
+                raise OSError('bbox_threshold should have 6 float values')
 
             mask_cc_part, cfa = segment_from_cfa(tensorfit, CC_box,
                                                  bbox_threshold,
@@ -554,7 +543,7 @@ class BundleShapeAnalysis(Workflow):
         populations. Sci Rep 10, 17149 (2020)
 
         """
-        rng = np.random.RandomState()
+        rng = np.random.default_rng()
         all_subjects = []
         if os.path.isdir(subject_folder):
             groups = os.listdir(subject_folder)
