@@ -17,7 +17,7 @@ The diffusion tensor models the diffusion signal as:
 
 .. math::
 
-    \frac{S(\mathbf{g}, b)}{S_0} = e^{-b\mathbf{g}^T \mathbf{D} \mathbf{g}}
+    \\frac{S(\\mathbf{g}, b)}{S_0} = e^{-b\\mathbf{g}^T \\mathbf{D} \\mathbf{g}}
 
 Where $\mathbf{g}$ is a unit vector in 3 space indicating the direction of
 measurement and b are the parameters of measurement, such as the strength and
@@ -29,9 +29,9 @@ parameters are:
 
 .. math::
 
-   \mathbf{D} = \begin{pmatrix} D_{xx} & D_{xy} & D_{xz} \\
+    \\mathbf{D} = \\begin{pmatrix} D_{xx} & D_{xy} & D_{xz} \\
                        D_{yx} & D_{yy} & D_{yz} \\
-                       D_{zx} & D_{zy} & D_{zz} \\ \end{pmatrix}
+                       D_{zx} & D_{zy} & D_{zz} \\ \\end{pmatrix}
 
 This matrix is a variance/covariance matrix of the diffusivity along the three
 spatial dimensions. Note that we can assume that diffusivity has antipodal
@@ -253,10 +253,9 @@ if interactive:
     window.show(scene)
 
 """
-.. figure:: tensor_ellipsoids.png
-   :align: center
+.. rst-class:: centered small fst-italic fw-semibold
 
-   Tensor Ellipsoids.
+Tensor Ellipsoids.
 """
 
 scene.clear()
@@ -277,10 +276,10 @@ if interactive:
     window.show(scene)
 
 """
-.. figure:: tensor_odfs.png
-   :align: center
+.. rst-class:: centered small fst-italic fw-semibold
+
+Tensor ODFs.
 
-   Tensor ODFs.
 
 Note that while the tensor model is an accurate and reliable model of the
 diffusion signal in the white matter, it has the drawback that it only has one
