@@ -12,16 +12,16 @@ Theory
 ======
 
 In QTI, the tissue microstructure is represented by a diffusion tensor
-distribution (DTD). Here, DTD is denoted by $\mathbf{D}$ and the voxel-level
-diffusion tensor from DTI by $\langle\mathbf{D}\rangle$, where
-$\langle \ \rangle$ denotes averaging over the DTD. The covariance of
-$\mathbf{D}$ is given by a fourth-order covariance tensor $\mathbb{C}$ defined
-as
+distribution (DTD). Here, DTD is denoted by $\\mathbf{D}$ and the voxel-level
+diffusion tensor from DTI by $\\langle\\mathbf{D}\\rangle$, where
+$\\langle \\ \\rangle$ denotes averaging over the DTD. The covariance of
+$\\mathbf{D}$ is given by a fourth-order covariance tensor $\\mathbb{C}$
+defined as
 
 .. math::
 
-   \mathbb{C} = \langle \mathbf{D} \otimes \mathbf{D} \rangle - \langle
-   \mathbf{D} \rangle \otimes \langle \mathbf{D} \rangle ,
+   \\mathbb{C} = \\langle \\mathbf{D} \\otimes \\mathbf{D} \\rangle - \\langle
+   \\mathbf{D} \\rangle \\otimes \\langle \\mathbf{D} \\rangle ,
 
 where $\otimes$ denotes a tensor outer product. $\mathbb{C}$ has 21 unique
 elements and enables the calculation of several microstructural parameters.
@@ -30,45 +30,46 @@ Using the cumulant expansion, the diffusion-weighted signal can be approximated
 as
 
 .. math::
-   S \approx S_0 \exp \left(- \mathbf{b} : \langle \mathbf{D} \rangle +
-   \frac{1}{2}(\mathbf{b} \otimes \mathbf{b}) : \mathbb{C} \right) ,
+   S \\approx S_0 \\exp \\left(- \\mathbf{b} : \\langle \\mathbf{D} \\rangle +
+   \\frac{1}{2}(\\mathbf{b} \\otimes \\mathbf{b}) : \\mathbb{C} \\right) ,
 
 where $S_0$ is the signal without diffusion-weighting, $\mathbf{b}$ is the
 b-tensor used in the acquisition, and $:$ denotes a tensor inner product.
 
-The model parameters $S_0$, $\langle\mathbf{D}\rangle$, and $\mathbb{C}$ can be
-estimated by solving the following equation:
+The model parameters $S_0$, $\\langle\\mathbf{D}\\rangle$, and $\\mathbb{C}$
+can be estimated by solving the following equation:
 
 .. math::
 
-   S = \beta X,
+   S = \\beta X,
 
 where
 
 .. math::
 
-   S = \begin{pmatrix} \ln S_1 \\ \vdots \\ \ln S_n \end{pmatrix} ,
+   S = \\begin{pmatrix} \\ln S_1 \\ \\vdots \\ \\ln S_n \\end{pmatrix} ,
 
 .. math::
 
-   \beta = \begin{pmatrix} \ln S_0 & \langle \mathbf{D} \rangle & \mathbb{C}
-   \end{pmatrix}^\text{T} ,
+   \\beta = \\begin{pmatrix} \\ln S_0 & \\langle \\mathbf{D}
+   \\rangle & \\mathbb{C} \\end{pmatrix}^\\text{T} ,
 
 .. math::
 
    X =
-   \begin{pmatrix}
-   1 & -\mathbf{b}_1^\text{T} & \frac{1}{2} (\mathbf{b}_1 \otimes \mathbf{b}_1)
-   \text{T} \\
-   \vdots & \vdots & \vdots \\
-   1 & -\mathbf{b}_n^\text{T} & \frac{1}{2} (\mathbf{b}_n \otimes \mathbf{b}_n)
-   ^\text{T}
-   \end{pmatrix} ,
+   \\begin{pmatrix}
+   1 & -\\mathbf{b}_1^\\text{T} & \\frac{1}{2} (\\mathbf{b}_1 \\otimes
+   \\mathbf{b}_1) \\text{T} \\
+   \\vdots & \\vdots & \\vdots \\
+   1 & -\\mathbf{b}_n^\\text{T} & \\frac{1}{2} (\\mathbf{b}_n \\otimes
+   \\mathbf{b}_n) ^\\text{T}
+   \\end{pmatrix} ,
 
-where $n$ is the number of acquisitions and $\langle\mathbf{D}\rangle$,
-$\mathbb{C}$, $\mathbf{b}_i$, and $(\mathbf{b}_i \otimes \mathbf{b}_i)$ are
-represented by column vectors using Voigt notation. Estimation of the model
-parameters requires that $\text{rank}(\mathbf{X}^\text{T}\mathbf{X}) = 28$.
+where $n$ is the number of acquisitions and $\\langle\\mathbf{D}\\rangle$,
+$\\mathbb{C}$, $\\mathbf{b}_i$, and $(\\mathbf{b}_i \\otimes \\mathbf{b}_i)$
+are represented by column vectors using Voigt notation. Estimation of the
+model parameters requires that
+$\\text{rank}(\\mathbf{X}^\\text{T}\\mathbf{X}) = 28$.
 This can be achieved by combining acquisitions with b-tensors with different
 shapes, sizes, and orientations.
 
@@ -89,10 +90,9 @@ import matplotlib.pyplot as plt
 import numpy as np
 import dipy.reconst.qti as qti
 
-"""
-As QTI requires data with tensor-valued encoding, let's load an example dataset
-acquired with q-space trajectory encoding (QTE):
-"""
+###############################################################################
+# As QTI requires data with tensor-valued encoding, let's load an example
+# dataset acquired with q-space trajectory encoding (QTE):
 
 fdata, fbvals, fbvecs, fmask = get_fnames('qte_lte_pte')
 data, affine = load_nifti(fdata)
@@ -101,39 +101,35 @@ bvals, bvecs = read_bvals_bvecs(fbvals, fbvecs)
 btens = np.array(['LTE' for i in range(61)] + ['PTE' for i in range(61)])
 gtab = gradient_table(bvals, bvecs, btens=btens)
 
-"""
-The dataset contains 122 volumes of which the first half were acquired with
-linear tensor encoding (LTE) and the second half with planar tensor encoding
-(PTE). We can confirm this by calculating the ranks of the b-tensors in the
-gradient table.
-"""
+###############################################################################
+# The dataset contains 122 volumes of which the first half were acquired with
+# linear tensor encoding (LTE) and the second half with planar tensor encoding
+# (PTE). We can confirm this by calculating the ranks of the b-tensors in the
+# gradient table.
 
 ranks = np.array([np.linalg.matrix_rank(b) for b in gtab.btens])
 for i, l in enumerate(['b = 0', 'LTE', 'PTE']):
     print('%s volumes with %s' % (np.sum(ranks == i), l))
 
-"""
-Now that we have data acquired with tensor-valued diffusion encoding and the
-corresponding gradient table containing the b-tensors, we can fit QTI to the
-data as follows:
-"""
+###############################################################################
+# Now that we have data acquired with tensor-valued diffusion encoding and the
+# corresponding gradient table containing the b-tensors, we can fit QTI to the
+# data as follows:
 
 qtimodel = qti.QtiModel(gtab)
 qtifit = qtimodel.fit(data, mask)
 
-"""
-QTI parameter maps can accessed as the attributes of `qtifit`. For instance,
-fractional anisotropy (FA) and microscopic fractional anisotropy (μFA) maps can
-be calculated as:
-"""
+###############################################################################
+# QTI parameter maps can accessed as the attributes of `qtifit`. For instance,
+# fractional anisotropy (FA) and microscopic fractional anisotropy (μFA) maps
+# can be calculated as:
 
 fa = qtifit.fa
 ufa = qtifit.ufa
 
-"""
-Finally, let's reproduce Figure 9 from [1]_ to visualize more QTI parameter
-maps:
-"""
+###############################################################################
+# Finally, let's reproduce Figure 9 from [1]_ to visualize more QTI parameter
+# maps:
 
 z = 36
 
@@ -181,12 +177,12 @@ ax[2, 3].set_title('K$_{μ}$')
 fig.tight_layout()
 plt.show()
 
-"""
-For more information about QTI, please read the article by Westin et al. [1]_.
-
-References
-----------
-.. [1] Westin, Carl-Fredrik, et al. "Q-space trajectory imaging for
-   multidimensional diffusion MRI of the human brain." Neuroimage 135
-   (2016): 345-362. https://doi.org/10.1016/j.neuroimage.2016.02.039.
-"""
+###############################################################################
+# For more information about QTI, please read the article by Westin et
+# al. [1]_.
+#
+# References
+# ----------
+# .. [1] Westin, Carl-Fredrik, et al. "Q-space trajectory imaging for
+#    multidimensional diffusion MRI of the human brain." Neuroimage 135
+#    (2016): 345-362. https://doi.org/10.1016/j.neuroimage.2016.02.039.
