@@ -51,7 +51,8 @@ Extending `Feature`
 ===================
 This section will guide you through the creation of a new feature extraction
 method that can be used in the context of this clustering framework. For a
-list of available features in DIPY see :ref:`example_segment_clustering_features`.
+list of available features in DIPY see
+:ref:`sphx_glr_examples_built_segmentation_segment_clustering_features.py`.
 
 Assuming a set of streamlines, the type of features we want to extract is the
 arc length (i.e. the sum of the length of each segment for a given streamline).
@@ -70,16 +71,16 @@ from dipy.segment.featurespeed import Feature, VectorOfEndpointsFeature
 from dipy.segment.metric import Metric, SumPointwiseEuclideanMetric
 from dipy.tracking.streamline import length
 
-"""
-We now define the class ``ArcLengthFeature`` that will perform the desired
-feature extraction. When subclassing ``Feature``, two methods have to be
-redefined: ``infer_shape`` and ``extract``.
+###############################################################################
+# We now define the class ``ArcLengthFeature`` that will perform the desired
+# feature extraction. When subclassing ``Feature``, two methods have to be
+# redefined: ``infer_shape`` and ``extract``.
+#
+# Also, an important property about feature extraction is whether or not
+# its process is invariant to the order of the points within a streamline.
+# This is needed as there is no way one can tell which extremity of a
+# streamline is the beginning and which one is the end.
 
-Also, an important property about feature extraction is whether or not
-its process is invariant to the order of the points within a streamline.
-This is needed as there is no way one can tell which extremity of a
-streamline is the beginning and which one is the end.
-"""
 
 class ArcLengthFeature(Feature):
     """ Computes the arc length of a streamline. """
@@ -94,18 +95,15 @@ class ArcLengthFeature(Feature):
 
     def extract(self, streamline):
         """ Extracts features from `streamline`. """
-        # return np.sum(np.sqrt(np.sum((streamline[1:] - streamline[:-1]) ** 2)))
-        # or use a DIPY's function that computes the arc length of a streamline.
         return length(streamline)
 
-"""
-The new feature extraction ``ArcLengthFeature`` is ready to be used. Let's use
-it to cluster a set of streamlines by their arc length. For educational
-purposes we will try to cluster a small streamline bundle known from
-neuroanatomy as the fornix.
-
-We start by loading the fornix streamlines.
-"""
+###############################################################################
+# The new feature extraction ``ArcLengthFeature`` is ready to be used. Let's
+# use it to cluster a set of streamlines by their arc length. For educational
+# purposes we will try to cluster a small streamline bundle known from
+# neuroanatomy as the fornix.
+#
+# We start by loading the fornix streamlines.
 
 fname = get_fnames('fornix')
 fornix = load_tractogram(fname, 'same',
@@ -113,18 +111,16 @@ fornix = load_tractogram(fname, 'same',
 
 streamlines = Streamlines(fornix)
 
-"""
-Perform QuickBundles clustering using the metric
-``SumPointwiseEuclideanMetric`` and our ``ArcLengthFeature``.
-"""
+###############################################################################
+# Perform QuickBundles clustering using the metric
+# ``SumPointwiseEuclideanMetric`` and our ``ArcLengthFeature``.
 
 metric = SumPointwiseEuclideanMetric(feature=ArcLengthFeature())
 qb = QuickBundles(threshold=2., metric=metric)
 clusters = qb.cluster(streamlines)
 
-"""
-We will now visualize the clustering result.
-"""
+###############################################################################
+# We will now visualize the clustering result.
 
 # Color each streamline according to the cluster they belong to.
 cmap = colormap.create_colormap(np.ravel(clusters.centroids))
@@ -142,44 +138,41 @@ interactive = False
 if interactive:
     window.show(scene)
 
-"""
-.. figure:: fornix_clusters_arclength.png
-   :align: center
-
-   Showing the different clusters obtained by using the arc length.
-
-
-Extending `Metric`
-==================
-This section will guide you through the creation of a new metric that can be
-used in the context of this clustering framework. For a list of available
-metrics in DIPY see :ref:`example_segment_clustering_metrics`.
-
-Assuming a set of streamlines, we want a metric that computes the cosine
-distance giving the vector between endpoints of each streamline (i.e. one
-minus the cosine of the angle between two vectors). For more information
-about this distance check `<http://en.wikipedia.org/wiki/Cosine_similarity>`_.
-
-Let's start by importing the necessary modules.
-"""
-
-"""
-We now define the class ``CosineMetric`` that will perform the desired
-distance computation. When subclassing ``Metric``, two methods have to be
-redefined: ``are_compatible`` and ``dist``. Moreover, when implementing the
-``dist`` method, one needs to make sure the distance returned is symmetric
-(i.e. `dist(A, B) == dist(B, A)`).
-"""
+###############################################################################
+# .. rst-class:: centered small fst-italic fw-semibold
+#
+# Showing the different clusters obtained by using the arc length.
+#
+#
+# Extending `Metric`
+# ==================
+# This section will guide you through the creation of a new metric that can be
+# used in the context of this clustering framework. For a list of available
+# metrics in DIPY see
+# :ref:`sphx_glr_examples_built_segmentation_segment_clustering_metrics.py`.
+#
+# Assuming a set of streamlines, we want a metric that computes the cosine
+# distance giving the vector between endpoints of each streamline (i.e. one
+# minus the cosine of the angle between two vectors). For more information
+# about this distance check
+# `<https://en.wikipedia.org/wiki/Cosine_similarity>`_.
+#
+# We now define the class ``CosineMetric`` that will perform the desired
+# distance computation. When subclassing ``Metric``, two methods have to be
+# redefined: ``are_compatible`` and ``dist``. Moreover, when implementing the
+# ``dist`` method, one needs to make sure the distance returned is symmetric
+# (i.e. `dist(A, B) == dist(B, A)`).
 
 
 class CosineMetric(Metric):
-    """ Computes the cosine distance between two streamlines. """
+    """Compute the cosine distance between two streamlines."""
     def __init__(self):
-        # For simplicity, features will be the vector between endpoints of a streamline.
+        # For simplicity, features will be the vector between endpoints of a
+        # streamline.
         super(CosineMetric, self).__init__(feature=VectorOfEndpointsFeature())
 
     def are_compatible(self, shape1, shape2):
-        """ Checks if two features are vectors of same dimension.
+        """Check if two features are vectors of same dimension.
 
         Basically this method exists so that we don't have to check
         inside the `dist` method (speedup).
@@ -187,7 +180,7 @@ class CosineMetric(Metric):
         return shape1 == shape2 and shape1[0] == 1
 
     def dist(self, v1, v2):
-        """ Computes a the cosine distance between two vectors. """
+        """Compute a the cosine distance between two vectors."""
         norm = lambda x: np.sqrt(np.sum(x**2))
         cos_theta = np.dot(v1, v2.T) / (norm(v1)*norm(v2))
 
@@ -197,30 +190,27 @@ class CosineMetric(Metric):
         return np.arccos(cos_theta) / np.pi  # Normalized cosine distance
 
 
-"""
-The new distance ``CosineMetric`` is ready to be used. Let's use
-it to cluster a set of streamlines according to the cosine distance of the
-vector between their endpoints. For educational purposes we will try to
-cluster a small streamline bundle known from neuroanatomy as the fornix.
-
-We start by loading the fornix streamlines.
-"""
+###############################################################################
+# The new distance ``CosineMetric`` is ready to be used. Let's use
+# it to cluster a set of streamlines according to the cosine distance of the
+# vector between their endpoints. For educational purposes we will try to
+# cluster a small streamline bundle known from neuroanatomy as the fornix.
+#
+# We start by loading the fornix streamlines.
 
 fname = get_fnames('fornix')
 fornix = load_tractogram(fname, 'same', bbox_valid_check=False)
 streamlines = fornix.streamlines
 
-"""
-Perform QuickBundles clustering using our metric ``CosineMetric``.
-"""
+###############################################################################
+# Perform QuickBundles clustering using our metric ``CosineMetric``.
 
 metric = CosineMetric()
 qb = QuickBundles(threshold=0.1, metric=metric)
 clusters = qb.cluster(streamlines)
 
-"""
-We will now visualize the clustering result.
-"""
+###############################################################################
+# We will now visualize the clustering result.
 
 # Color each streamline according to the cluster they belong to.
 cmap = colormap.create_colormap(np.arange(len(clusters)))
@@ -235,19 +225,16 @@ window.record(scene, out_path='fornix_clusters_cosine.png', size=(600, 600))
 if interactive:
     window.show(scene)
 
-"""
-.. figure:: fornix_clusters_cosine.png
-   :align: center
-
-   Showing the different clusters obtained by using the cosine metric.
-
-.. include:: ../links_names.inc
-
-References
-----------
-
-.. [Garyfallidis12] Garyfallidis E. et al., QuickBundles a method for
-   tractography simplification, Frontiers in Neuroscience, vol 6, no 175,
-   2012.
-
-"""
+###############################################################################
+# .. rst-class:: centered small fst-italic fw-semibold
+#
+# Showing the different clusters obtained by using the cosine metric.
+#
+#
+#
+# References
+# ----------
+#
+# .. [Garyfallidis12] Garyfallidis E. et al., QuickBundles a method for
+#    tractography simplification, Frontiers in Neuroscience, vol 6, no 175,
+#    2012.
