@@ -7,9 +7,15 @@ import pydoc
 from warnings import warn
 import collections
 import sys
+from packaging.version import Version
 
+python_version = '.'.join(str(x) for x in sys.version_info[:2])
+if Version(python_version) >= Version('3.10'):
+    from collections.abc import Mapping
+else:
+    from collections import Mapping
 
-class Reader(object):
+class Reader:
     """A line-based string reader.
 
     """
@@ -85,7 +91,8 @@ class Reader(object):
         return not ''.join(self._str).strip()
 
 
-class NumpyDocString(collections.Mapping):
+class NumpyDocString(Mapping):
+
     def __init__(self, docstring, config={}):
         docstring = textwrap.dedent(docstring).split('\n')
 
@@ -117,7 +124,7 @@ class NumpyDocString(collections.Mapping):
 
     def __setitem__(self, key, val):
         if key not in self._parsed_data:
-            warn("Unknown section %s" % key)
+            warn(f"Unknown section {key}")
         else:
             self._parsed_data[key] = val
 
@@ -216,7 +223,7 @@ class NumpyDocString(collections.Mapping):
                     return g[3], None
                 else:
                     return g[2], g[1]
-            raise ValueError("%s is not a item name" % text)
+            raise ValueError(f"{text} is not a item name")
 
         def push_item(name, rest):
             if not name:
@@ -357,7 +364,7 @@ class NumpyDocString(collections.Mapping):
             out += self._str_header(name)
             for param, param_type, desc in self[name]:
                 if param_type:
-                    out += ['%s : %s' % (param, param_type)]
+                    out += [f'{param} : {param_type}']
                 else:
                     out += [param]
                 out += self._str_indent(desc)
@@ -380,16 +387,16 @@ class NumpyDocString(collections.Mapping):
         last_had_desc = True
         for func, desc, role in self['See Also']:
             if role:
-                link = ':%s:`%s`' % (role, func)
+                link = f':{role}:`{func}`'
             elif func_role:
-                link = ':%s:`%s`' % (func_role, func)
+                link = f':{func_role}:`{func}`'
             else:
-                link = "`%s`_" % func
+                link = f"`{func}`_"
             if desc or last_had_desc:
                 out += ['']
                 out += [link]
             else:
-                out[-1] += ", %s" % link
+                out[-1] += f", {link}"
             if desc:
                 out += self._str_indent([' '.join(desc)])
                 last_had_desc = True
@@ -401,11 +408,12 @@ class NumpyDocString(collections.Mapping):
     def _str_index(self):
         idx = self['index']
         out = []
-        out += ['.. index:: %s' % idx.get('default', '')]
+        default_section = idx.get('default', '')
+        out += [f'.. index:: {default_section}']
         for section, references in idx.items():
             if section == 'default':
                 continue
-            out += ['   :%s: %s' % (section, ', '.join(references))]
+            out += [f'   :{section}: {references}']
         return out
 
     def __str__(self, func_role=''):
@@ -464,9 +472,9 @@ class FunctionDoc(NumpyDocString):
                     argspec = inspect.getargspec(func)
                 argspec = inspect.formatargspec(*argspec)
                 argspec = argspec.replace('*', '\*')
-                signature = '%s%s' % (func_name, argspec)
+                signature = f'{func_name}{argspec}'
             except TypeError:
-                signature = '%s()' % func_name
+                signature = f'{func_name}()'
             self['Signature'] = signature
 
     def get_func(self):
@@ -487,9 +495,9 @@ class FunctionDoc(NumpyDocString):
 
         if self._role:
             if self._role not in roles:
-                print("Warning: invalid role %s" % self._role)
-            out += '.. %s:: %s\n    \n\n' % (roles.get(self._role, ''),
-                                             func_name)
+                print(f"Warning: invalid role {self._role}")
+            self_role = roles.get(self._role, '')
+            out += f'.. {self_role}:: {func_name}\n    \n\n'
 
         out += super(FunctionDoc, self).__str__(func_role=self._role)
         return out
@@ -502,7 +510,7 @@ class ClassDoc(NumpyDocString):
     def __init__(self, cls, doc=None, modulename='', func_doc=FunctionDoc,
                  config={}):
         if not inspect.isclass(cls) and cls is not None:
-            raise ValueError("Expected a class or None, but got %r" % cls)
+            raise ValueError(f"Expected a class or None, but got {cls!r}")
         self._cls = cls
 
         self.show_inherited_members = config.get(
