@@ -5,7 +5,7 @@ source tools/ci/activate_env.sh
 
 set -ex
 
-PIPI="pip install --timeout=60"
+PIPI="pip install --timeout=60 -Csetup-args=--vsenv -Ccompile-args=-v"
 
 if [ "$USE_PRE" == "1" ] || [ "$USE_PRE" == true ]; then
     PIPI="$PIPI --extra-index-url=$PRE_WHEELS --pre";
@@ -16,7 +16,7 @@ fi
 if [ "$INSTALL_TYPE" == "setup" ]; then
     python setup.py install
 elif [ "$INSTALL_TYPE" == "pip" ]; then
-    $PIPI .
+    $PIPI -vv .
 elif [ "$INSTALL_TYPE" == "sdist" ]; then
     # python -m pep517.build
     python setup_egg.py egg_info  # check egg_info while we're here
@@ -30,7 +30,7 @@ elif [ "$INSTALL_TYPE" == "requirements" ]; then
     $PIPI -r requirements.txt
     python setup.py install
 elif [ "$INSTALL_TYPE" == "conda" ]; then
-    $PIPI .
+    $PIPI -vv .
 fi
 
 set +ex
\ No newline at end of file
