@@ -16,14 +16,14 @@ if [ "$INSTALL_TYPE" == "conda" ]; then
 else
     PIPI="pip install --timeout=60 "
 
-    if [ "$USE_PRE" == "1" ] || [ "$USE_PRE" = true ]; then
+    if [ "$USE_PRE" == "1" ] || [ "$USE_PRE" == true ]; then
         PIPI="$PIPI --extra-index-url=$PRE_WHEELS --pre";
     fi
 
     $PIPI pytest
     $PIPI numpy
     if [ -n "$DEPENDS" ]; then $PIPI $DEPENDS $EXTRA_DEPENDS; fi
-    if [ "$COVERAGE" == "1" ] || [ "$COVERAGE" = true ]; then pip install coverage coveralls codecov; fi
+    if [ "$COVERAGE" == "1" ] || [ "$COVERAGE" = true ]; then pip install coverage coveralls; fi
 fi
 
 set +ex
