@@ -11,18 +11,18 @@ echo "Run the tests"
 mkdir for_testing
 cd for_testing
 # We need the setup.cfg for the pytest settings
-cp ../setup.cfg .
+cp ../pyproject.toml .
 # No figure windows for mpl; quote to hide : from travis-ci yaml parsing
 echo "backend : agg" > matplotlibrc
 if [ "$COVERAGE" == "1" ] || [ "$COVERAGE" == true ]; then
     cp ../.coveragerc .;
     cp ../.codecov.yml .;
     # Run the tests and check for test coverage.
-    coverage run -m pytest -svv --doctest-modules --verbose --durations=10 --pyargs dipy
+    coverage run -m pytest -c pyproject.toml -svv --doctest-modules --verbose --durations=10 --pyargs dipy
     coverage report -m  # Generate test coverage report.
     coverage xml  # Generate coverage report in xml format for codecov upload.
 else
-    pytest -svv --doctest-modules --verbose --durations=10 --pyargs dipy
+    pytest -c pyproject.toml -svv --doctest-modules --verbose --durations=10 --pyargs dipy
 fi
 cd ..
 set +ex
\ No newline at end of file
